<?php

// line 11 "src/Parser/TemplateParser.y"


namespace Smarty\Parser;

use \Smarty\Lexer\TemplateLexer as Lexer;
use \Smarty\ParseTree\Template as TemplateParseTree;
use \Smarty\Compiler\Template as TemplateCompiler;
use \Smarty\ParseTree\Code;
use \Smarty\ParseTree\Dq;
use \Smarty\ParseTree\DqContent;
use \Smarty\ParseTree\Tag;


/**
* Smarty Template Parser Class
*
* This is the template parser.
* It is generated from the TemplateParser.y file
* 
* @author Uwe Tews <uwe.tews@googlemail.com>
*/
class TemplateParser
{
// line 35 "src/Parser/TemplateParser.y"

    const ERR1 = 'Security error: Call to private object member not allowed';
    const ERR2 = 'Security error: Call to dynamic object member not allowed';

    /**
     * result status
     *
     * @var bool
     */
    public $successful = true;

    /**
     * return value
     *
     * @var mixed
     */
    public $retvalue = 0;

    /**
     * @var
     */
    public $yymajor;

    /**
     * last index of array variable
     *
     * @var mixed
     */
    public $last_index;

    /**
     * last variable name
     *
     * @var string
     */
    public $last_variable;

    /**
     * root parse tree buffer
     *
     * @var TemplateParseTree
     */
    public $root_buffer;

    /**
     * current parse tree object
     *
     * @var \Smarty\ParseTree\Base
     */
    public $current_buffer;

    /**
     * lexer object
     *
     * @var Lexer
     */
    public $lex;

    /**
     * internal error flag
     *
     * @var bool
     */
    private $internalError = false;

    /**
     * {strip} status
     *
     * @var bool
     */
    public $strip = false;
    /**
     * compiler object
     *
     * @var TemplateCompiler
     */
    public $compiler = null;

    /**
     * smarty object
     *
     * @var \Smarty\Smarty
     */
    public $smarty = null;

    /**
     * template object
     *
     * @var \Smarty\Template
     */
    public $template = null;

    /**
     * block nesting level
     *
     * @var int
     */
    public $block_nesting_level = 0;

    /**
     * security object
     *
     * @var \Smarty\Security
     */
    public $security = null;

    /**
     * template prefix array
     *
     * @var \Smarty\ParseTree\Base[]
     */
    public $template_prefix = array();

    /**
     * template prefix array
     *
     * @var \Smarty\ParseTree\Base[]
     */
    public $template_postfix = array();

    /**
     * constructor
     *
     * @param Lexer        $lex
     * @param TemplateCompiler $compiler
     */
    public function __construct(Lexer $lex, TemplateCompiler $compiler)
    {
        $this->lex = $lex;
        $this->compiler = $compiler;
        $this->template = $this->compiler->getTemplate();
        $this->smarty = $this->template->getSmarty();
        $this->security = $this->smarty->security_policy ?? false;
        $this->current_buffer = $this->root_buffer = new TemplateParseTree();
    }

     /**
     * insert PHP code in current buffer
     *
     * @param string $code
     */
    public function insertPhpCode($code)
    {
        $this->current_buffer->append_subtree($this, new Tag($this, $code));
    }

    /**
     * error rundown
     *
     */
    public function errorRunDown()
    {
        while ($this->yystack !== array()) {
            $this->yy_pop_parser_stack();
        }
        if (is_resource($this->yyTraceFILE)) {
            fclose($this->yyTraceFILE);
        }
    }

    /**
     *  merge PHP code with prefix code and return parse tree tag object
     *
     * @param string $code
     *
     * @return Tag
     */
    private function mergePrefixCode($code)
    {
        $tmp = '';
        foreach ($this->compiler->prefix_code as $preCode) {
            $tmp .= $preCode;
        }
        $this->compiler->prefix_code = array();
        $tmp .= $code;
        return new Tag($this, $this->compiler->processNocacheCode($tmp));
    }


    const TP_VERT                           =  1;
    const TP_COLON                          =  2;
    const TP_TEXT                           =  3;
    const TP_STRIPON                        =  4;
    const TP_STRIPOFF                       =  5;
    const TP_LITERALSTART                   =  6;
    const TP_LITERALEND                     =  7;
    const TP_LITERAL                        =  8;
    const TP_SIMPELOUTPUT                   =  9;
    const TP_SIMPLETAG                      = 10;
    const TP_SMARTYBLOCKCHILDPARENT         = 11;
    const TP_LDEL                           = 12;
    const TP_RDEL                           = 13;
    const TP_DOLLARID                       = 14;
    const TP_EQUAL                          = 15;
    const TP_ID                             = 16;
    const TP_PTR                            = 17;
    const TP_LDELIF                         = 18;
    const TP_LDELFOR                        = 19;
    const TP_SEMICOLON                      = 20;
    const TP_INCDEC                         = 21;
    const TP_TO                             = 22;
    const TP_STEP                           = 23;
    const TP_LDELFOREACH                    = 24;
    const TP_SPACE                          = 25;
    const TP_AS                             = 26;
    const TP_APTR                           = 27;
    const TP_LDELSETFILTER                  = 28;
    const TP_CLOSETAG                       = 29;
    const TP_LDELSLASH                      = 30;
    const TP_ATTR                           = 31;
    const TP_INTEGER                        = 32;
    const TP_COMMA                          = 33;
    const TP_OPENP                          = 34;
    const TP_CLOSEP                         = 35;
    const TP_MATH                           = 36;
    const TP_UNIMATH                        = 37;
    const TP_ISIN                           = 38;
    const TP_QMARK                          = 39;
    const TP_NOT                            = 40;
    const TP_TYPECAST                       = 41;
    const TP_HEX                            = 42;
    const TP_DOT                            = 43;
    const TP_INSTANCEOF                     = 44;
    const TP_SINGLEQUOTESTRING              = 45;
    const TP_DOUBLECOLON                    = 46;
    const TP_NAMESPACE                      = 47;
    const TP_AT                             = 48;
    const TP_HATCH                          = 49;
    const TP_OPENB                          = 50;
    const TP_CLOSEB                         = 51;
    const TP_DOLLAR                         = 52;
    const TP_LOGOP                          = 53;
    const TP_SLOGOP                         = 54;
    const TP_TLOGOP                         = 55;
    const TP_SINGLECOND                     = 56;
    const TP_ARRAYOPEN                      = 57;
    const TP_QUOTE                          = 58;
    const TP_BACKTICK                       = 59;
    const YY_NO_ACTION = 525;
    const YY_ACCEPT_ACTION = 524;
    const YY_ERROR_ACTION = 523;

    const YY_SZ_ACTTAB = 2191;
public static $yy_action = array(
     33,  126,  524,   96,  261,  279,  437,  242,  243,  244,
      1,   98,  135,  127,  199,  228,    6,   55,  437,  217,
    197,  260,  109,  317,  392,  292,  212,  256,  213,  103,
    219,  392,   21,  392,   99,   43,  392,   32,   44,   45,
    273,  221,  392,  277,  392,  200,  392,   54,    4,  313,
    294,   46,   22,  280,  220,    5,   52,  242,  243,  244,
      1,   20,  132,  189,  190,  266,    6,   55,  241,  217,
    211,   29,  109,  224,    9,  156,  212,  256,  213,  493,
    205,  267,   21,  252,  264,   43,  176,  297,   44,   45,
    273,  221,  312,  230,  306,  200,  211,   54,    4,  320,
    294,  294,    3,  248,   99,    5,   52,  242,  243,  244,
      1,  294,   97,  386,   53,  231,    6,   55,   36,  217,
     99,  150,  109,  252,   16,  386,  212,  256,  213,  149,
    219,  386,   21,  112,  437,   43,  302,   93,   44,   45,
    273,  221,  306,  277,  211,  200,  437,   54,    4,  112,
    294,  197,   39,   99,  140,    5,   52,  242,  243,  244,
      1,  136,  134,  262,  199,   28,    6,   55,  155,  217,
    252,  151,  109,   99,   94,   91,  212,  256,  213,  137,
    219,  251,   21,   57,  308,   43,   13,    7,   44,   45,
    273,  221,  294,  277,  263,  200,   54,   54,    4,  294,
    294,  181,  112,  298,  197,    5,   52,  242,  243,  244,
      1,  259,  134,  232,  191,  353,    6,   55,   26,  217,
    330,  353,  109,  104,  149,  437,  212,  256,  213,  174,
    219,  222,   21,  250,   51,   43,  141,  437,   44,   45,
    273,  221,  232,  277,  296,  200,  251,   54,    4,  233,
    294,   35,  104,  353,  285,    5,   52,  242,  243,  244,
      1,  259,  133,  138,  199,  353,    6,   55,  108,  217,
    173,  353,  109,  175,  297,   14,  212,  256,  213,  450,
    219,   15,   11,  264,   51,   43,  450,  139,   44,   45,
    273,  221,  144,  277,  152,  200,  181,   54,    4,  136,
    294,  226,  251,  154,  251,    5,   52,  242,  243,  244,
      1,  146,  134,  251,  186,  197,    6,   55,  170,  217,
    157,  251,  109,   17,  180,  294,  212,  256,  213,  329,
    208,  215,   21,  180,   54,   43,  252,  294,   44,   45,
    273,  221,  143,  277,  181,  200,  254,   54,    4,   19,
    294,  126,  104,  253,  227,    5,   52,  242,  243,  244,
      1,   98,  134,  259,  184,  161,    6,   55,  178,  217,
    240,  148,  109,  175,  297,  292,  212,  256,  213,  284,
    219,  251,   21,  197,   23,   43,   51,  127,   44,   45,
    273,  221,  164,  277,  168,  200,  252,   54,    4,  171,
    294,  304,  251,  197,  327,    5,   52,  242,  243,  244,
      1,  137,  134,  167,  199,  180,    6,   55,   13,  217,
    181,  255,  109,  251,   87,  181,  212,  256,  213,   25,
    185,   18,   21,  177,  297,   43,   88,   15,   44,   45,
    273,  221,  294,  277,   24,  200,  295,   54,    4,  258,
    294,   41,   42,   40,   12,    5,   52,  242,  243,  244,
      1,  163,  136,  437,  199,   39,    6,   55,  287,  288,
    289,  290,  109,  259,  303,  437,  212,  256,  213,  450,
    219,  214,   21,  209,  194,   47,  450,  438,   44,   45,
    273,  221,    9,  277,  309,  200,   51,   54,    4,  438,
    294,   41,   42,   40,   12,    5,   52,  242,  243,  244,
      1,   10,  136,   24,  199,  321,    6,   55,  287,  288,
    289,  290,  109,  113,  239,  240,  212,  256,  213,  220,
    219,  255,   21,    8,   24,   43,  322,  316,   44,   45,
    273,  221,   89,  277,  293,  200,  195,   54,    4,   95,
    294,   34,  169,  172,  238,    5,   52,  282,  210,  211,
    247,  232,   90,  106,  158,  188,  100,   86,  234,  196,
    254,  104,   98,   19,  153,  268,  269,  253,   92,  220,
    159,  276,  201,  278,  251,  283,  292,  245,  282,  210,
    211,  247,  466,   90,  106,  466,  187,  100,   63,  466,
    246,  179,  110,   98,  181,  165,  268,  269,  257,  223,
    118,  265,  276,  201,  278,  251,  283,  292,   46,   22,
    280,  282,  270,  211,  249,  272,  111,  106,  274,  188,
    100,   86,  220,  282,  275,  211,   98,  259,  111,  268,
    269,  198,  116,   75,    7,  276,  201,  278,   98,  283,
    292,  268,  269,  145,  291,   56,  160,  276,  201,  278,
     51,  283,  292,   41,   42,   40,   12,  315,  162,  282,
    229,  211,  204,  311,  111,  318,  197,  198,  116,   75,
    287,  288,  289,  290,   98,  319,   36,  268,  269,  197,
    328,  331,  301,  276,  201,  278,  301,  283,  292,   37,
     14,  357,  282,  301,  211,  225,   15,  105,  203,  311,
    198,  119,   49,   14,  117,  301,  301,   98,  301,   15,
    268,  269,  437,  301,  301,  301,  276,  201,  278,  301,
    283,  292,  301,  301,  437,  282,  301,  211,  301,  301,
    111,  301,  301,  198,  119,   70,  301,  301,  301,  301,
     98,  301,  142,  268,  269,  301,  301,  301,  301,  276,
    201,  278,  251,  283,  292,   46,   22,  280,  282,  301,
    211,  207,  301,  111,  301,  301,  198,  119,   70,  301,
    301,  301,  301,   98,  301,  166,  268,  269,  301,  301,
    301,  301,  276,  201,  278,  251,  283,  292,   46,   22,
    280,  282,  301,  211,  202,  301,  111,  301,  301,  198,
    116,   75,  301,  301,  301,  301,   98,  301,  301,  268,
    269,  197,  301,  301,  301,  276,  201,  278,  301,  283,
    292,  301,  301,  354,  282,  301,  211,  301,  301,  111,
    301,  310,  198,  119,   70,  354,  301,  301,  301,   98,
    301,  354,  268,  269,  197,  301,  301,  301,  276,  201,
    278,  301,  283,  292,  301,  301,  388,  282,  301,  211,
    206,  301,  105,  301,  301,  198,  119,   61,  388,  233,
    301,  301,   98,  301,  388,  268,  269,  197,  301,  301,
    301,  276,  201,  278,  301,  283,  292,  301,  301,  385,
    282,  301,  211,  301,  301,  111,  301,  301,  198,  115,
     67,  385,  301,  301,  301,   98,  301,  385,  268,  269,
    301,  301,  301,  301,  276,  201,  278,  254,  283,  292,
     19,  301,  301,  282,  253,  211,  301,  466,  111,  301,
    466,  193,  114,   62,  466,  282,  301,  211,   98,  301,
    111,  268,  269,  198,  101,   85,  301,  276,  201,  278,
     98,  283,  292,  268,  269,  254,  216,  301,   19,  276,
    201,  278,  253,  283,  292,  282,  466,  211,  301,  301,
    111,   14,  301,  198,  102,   84,  301,   15,  301,  301,
     98,  301,  301,  268,  269,  301,  301,  301,  301,  276,
    201,  278,  301,  283,  292,  301,  301,  282,  301,  211,
    301,  301,  111,  301,  301,  198,  119,   58,  301,  282,
    301,  211,   98,  301,  111,  268,  269,  198,  119,   69,
    301,  276,  201,  278,   98,  283,  292,  268,  269,  301,
    301,  301,  301,  276,  201,  278,  301,  283,  292,  282,
    301,  211,  301,  301,  111,  301,  301,  198,  101,   59,
    301,  301,  301,  301,   98,  301,  301,  268,  269,  301,
    301,  301,  301,  276,  201,  278,  301,  283,  292,  301,
    301,  282,  301,  211,  301,  301,  111,  301,  301,  198,
    119,   68,  301,  282,  301,  211,   98,  301,  111,  268,
    269,  198,  119,   60,  301,  276,  201,  278,   98,  283,
    292,  268,  269,  301,  301,  301,  301,  276,  201,  278,
    301,  283,  292,  282,  301,  211,  301,  301,  111,  301,
    301,  198,  119,   61,  301,  301,  301,  301,   98,  301,
    301,  268,  269,  301,  301,  301,  301,  276,  201,  278,
    301,  283,  292,  301,  301,  282,  301,  211,  301,  301,
    111,  301,  301,  198,  119,   71,  301,  282,  301,  211,
     98,  301,  111,  268,  269,  198,  119,   72,  301,  276,
    201,  278,   98,  283,  292,  268,  269,  301,  301,  301,
    301,  276,  201,  278,  301,  283,  292,  282,  301,  211,
    301,  301,  111,  301,  301,  198,  119,   73,  301,  301,
    301,  301,   98,  301,  301,  268,  269,  301,  301,  301,
    301,  276,  201,  278,  301,  283,  292,  301,  301,  282,
    301,  211,  301,  301,  111,  301,  301,  198,  119,   74,
    301,  282,  301,  211,   98,  301,  111,  268,  269,  198,
    119,   76,  301,  276,  201,  278,   98,  283,  292,  268,
    269,  301,  301,  301,  301,  276,  201,  278,  301,  283,
    292,  282,  301,  211,  301,  301,  111,  301,  301,  192,
    119,   64,  301,  301,  301,  301,   98,  301,  301,  268,
    269,  301,  301,  301,  301,  276,  201,  278,  301,  283,
    292,  301,  301,  282,  301,  211,  301,  301,  111,  301,
    301,  198,  119,   65,  301,  282,  301,  211,   98,  301,
    111,  268,  269,  198,  119,   66,  301,  276,  201,  278,
     98,  283,  292,  268,  269,  301,  301,  301,  301,  276,
    201,  278,  301,  283,  292,  282,  301,  211,  301,  301,
    111,  301,  301,  198,  119,   77,  301,  301,  301,  301,
     98,  301,  301,  268,  269,  301,  301,  301,  301,  276,
    201,  278,  301,  283,  292,  301,  301,  282,  301,  211,
    301,  301,  111,  301,  301,  198,  119,   78,  301,  282,
    301,  211,   98,  301,  111,  268,  269,  198,  119,   79,
    301,  276,  201,  278,   98,  283,  292,  268,  269,  301,
    301,  301,  301,  276,  201,  278,  301,  283,  292,  282,
    301,  211,  301,  301,  111,  301,  301,  198,  119,   80,
    301,  301,  301,  301,   98,  301,  301,  268,  269,  301,
    301,  301,  301,  276,  201,  278,  301,  283,  292,  301,
    301,  282,  301,  211,  301,  301,  111,  301,  301,  198,
    119,   81,  301,  282,  301,  211,   98,  301,  111,  268,
    269,  198,  119,   82,  301,  276,  201,  278,   98,  283,
    292,  268,  269,  301,  301,  301,  301,  276,  201,  278,
    301,  283,  292,  282,  301,  211,  301,  301,  111,  301,
    301,  198,  119,   83,  301,  301,  301,  301,   98,  301,
    301,  268,  269,  301,  301,  301,  301,  276,  201,  278,
    301,  283,  292,  301,  301,  282,  301,  211,  301,  301,
    111,  301,  301,  198,  119,   48,  301,  282,  301,  211,
     98,  301,  111,  268,  269,  198,  119,   50,  301,  276,
    201,  278,   98,  283,  292,  268,  269,  301,  301,  301,
    301,  276,  201,  278,  301,  283,  292,  307,  107,  301,
    301,  301,  301,  242,  243,  244,    2,  301,  305,  301,
    301,  301,    6,   55,   41,   42,   40,   12,  109,  301,
    301,  301,  212,  256,  213,  301,  301,   38,  301,   14,
    301,  287,  288,  289,  290,   15,  301,  301,  301,  301,
     41,   42,   40,   12,  301,  301,  301,  301,  301,  301,
    301,  301,  300,   27,  301,  301,  307,  287,  288,  289,
    290,  301,  242,  243,  244,    2,  301,  305,  301,  301,
    301,    6,   55,  301,  301,  301,  301,  109,  301,   14,
    301,  212,  256,  213,  301,   15,  301,  301,  301,  301,
     41,   42,   40,   12,  301,  301,  301,  301,  301,  301,
    301,  301,  301,  301,  301,  301,  301,  287,  288,  289,
    290,  301,   27,  301,  301,  235,  236,  237,  130,  301,
    301,  242,  243,  244,    1,  301,  301,  301,  301,  301,
      6,   55,  301,  301,  301,  301,  109,  301,  301,  301,
    212,  256,  213,  282,  301,  211,  301,  301,  111,  301,
    301,  198,  131,  301,  301,  301,  301,  301,   98,  301,
    301,  301,  301,  301,  301,  301,  325,  276,  201,  278,
    301,  283,  292,  301,  301,  301,  301,  301,  282,  301,
    211,  301,  301,  111,  301,  301,  198,  125,  301,  301,
    282,  301,  211,   98,  301,  111,  301,  301,  198,  129,
    301,  281,  276,  201,  278,   98,  283,  292,  301,  301,
    301,  301,  301,  301,  276,  201,  278,  301,  283,  292,
    301,  301,  301,  301,  282,  301,  211,  301,  301,  111,
    301,  301,  198,  120,  301,  301,  301,  301,  301,   98,
    301,  301,  301,  301,  301,  301,  301,  301,  276,  201,
    278,  301,  283,  292,  301,  301,  282,  301,  211,  301,
    301,  111,  301,  301,  198,  121,  301,  301,  282,  301,
    211,   98,  301,  111,  301,  301,  198,  122,  301,  301,
    276,  201,  278,   98,  283,  292,  301,  301,  301,  301,
    301,  301,  276,  201,  278,  301,  283,  292,  282,  301,
    211,  301,  301,  111,  301,  301,  198,  123,  301,  301,
    301,  301,  301,   98,  301,  301,  301,  301,  301,  301,
    301,  301,  276,  201,  278,  301,  283,  292,  301,  301,
    282,  301,  211,  301,  301,  111,  301,  301,  198,  124,
    301,  301,  282,  301,  211,   98,  301,  111,  301,  301,
    198,  128,  301,  301,  276,  201,  278,   98,  283,  292,
    301,  301,  218,  301,  301,  301,  276,  201,  278,  466,
    283,  292,  466,  218,  301,    3,  466,  450,  301,  301,
    466,  271,  301,  466,  301,  301,  218,  466,  450,  301,
    301,  254,  271,  466,   19,  301,  466,  301,  253,   35,
    466,  450,  301,  450,  401,  271,  450,   14,  466,  147,
    450,  301,  301,   15,  450,  301,  301,  450,  301,  466,
    301,  450,  286,  301,  301,  301,  301,  450,  301,  301,
    450,  301,  466,  301,  450,  218,  437,  301,  401,  401,
    401,  401,  466,  301,  301,  466,  301,  301,  437,  466,
    450,  301,   30,  301,  271,  401,  401,  401,  401,  466,
    301,  301,  466,  301,  324,  301,  466,  450,  301,  301,
    301,  271,  301,  301,  301,  301,  450,  301,  301,  450,
    301,  466,  301,  450,  301,  301,  301,   41,   42,   40,
     12,  301,  301,  450,  301,  299,  450,  301,  466,  301,
    450,  301,  301,  301,  287,  288,  289,  290,   41,   42,
     40,   12,  323,   41,   42,   40,   12,  301,   41,   42,
     40,   12,  182,  314,   31,  287,  288,  289,  290,  183,
    287,  288,  289,  290,  301,  287,  288,  289,  290,  301,
    301,  301,  301,  301,  301,   41,   42,   40,   12,  301,
    301,  301,   41,   42,   40,   12,  301,  301,   41,   42,
     40,   12,  287,  288,  289,  290,  326,  301,  301,  287,
    288,  289,  290,  301,  301,  287,  288,  289,  290,  466,
    301,  301,  466,  301,  301,  301,  466,  450,  301,   41,
     42,   40,   12,  301,  301,  301,  301,  301,  301,  301,
    301,  301,  301,  301,  301,  301,  287,  288,  289,  290,
    301,  301,  301,  450,  301,  301,  450,  301,  466,  301,
    450,
    );
    public static $yy_lookahead = array(
      2,   70,   61,   62,   73,   92,   34,    9,   10,   11,
     12,   80,   14,  100,   16,   43,   18,   19,   46,   21,
      1,   90,   24,   51,   13,   94,   28,   29,   30,   80,
     32,   20,   34,   22,   17,   37,   25,   39,   40,   41,
     42,   43,   31,   45,   33,   47,   35,   49,   50,  100,
     52,   85,   86,   87,   43,   57,   58,    9,   10,   11,
     12,   12,   14,   14,   16,   16,   18,   19,   65,   21,
     67,   12,   24,   14,   33,   16,   28,   29,   30,    1,
     32,   32,   34,   97,   96,   37,   98,   99,   40,   41,
     42,   43,   51,   45,   65,   47,   67,   49,   50,   51,
     52,   52,   15,   69,   17,   57,   58,    9,   10,   11,
     12,   52,   14,   13,   16,   15,   18,   19,   15,   21,
     17,   95,   24,   97,   20,   25,   28,   29,   30,   95,
     32,   31,   34,   46,   34,   37,  107,   33,   40,   41,
     42,   43,   65,   45,   67,   47,   46,   49,   50,   46,
     52,    1,    2,   17,   14,   57,   58,    9,   10,   11,
     12,   14,   14,   16,   16,   12,   18,   19,   95,   21,
     97,   72,   24,   17,   34,   76,   28,   29,   30,   43,
     32,   82,   34,  106,  107,   37,   50,   34,   40,   41,
     42,   43,   52,   45,   47,   47,   49,   49,   50,   52,
     52,  102,   46,   13,    1,   57,   58,    9,   10,   11,
     12,   21,   14,   70,   16,   25,   18,   19,   27,   21,
     77,   31,   24,   80,   95,   34,   28,   29,   30,   14,
     32,   16,   34,   82,   44,   37,   72,   46,   40,   41,
     42,   43,   70,   45,   69,   47,   82,   49,   50,   77,
     52,   15,   80,   13,   51,   57,   58,    9,   10,   11,
     12,   21,   14,   80,   16,   25,   18,   19,   79,   21,
     76,   31,   24,   98,   99,   25,   28,   29,   30,   43,
     32,   31,   34,   96,   44,   37,   50,   14,   40,   41,
     42,   43,   72,   45,   72,   47,  102,   49,   50,   14,
     52,   16,   82,   72,   82,   57,   58,    9,   10,   11,
     12,   72,   14,   82,   16,    1,   18,   19,   76,   21,
     95,   82,   24,   15,  102,   52,   28,   29,   30,   21,
     32,   17,   34,  102,   49,   37,   97,   52,   40,   41,
     42,   43,   70,   45,  102,   47,    9,   49,   50,   12,
     52,   70,   80,   16,   73,   57,   58,    9,   10,   11,
     12,   80,   14,   21,   16,   95,   18,   19,    6,   21,
      8,   72,   24,   98,   99,   94,   28,   29,   30,   92,
     32,   82,   34,    1,    2,   37,   44,  100,   40,   41,
     42,   43,   72,   45,   76,   47,   97,   49,   50,   76,
     52,   59,   82,    1,   14,   57,   58,    9,   10,   11,
     12,   43,   14,   72,   16,  102,   18,   19,   50,   21,
    102,  103,   24,   82,   80,  102,   28,   29,   30,   27,
     32,   25,   34,   98,   99,   37,   80,   31,   40,   41,
     42,   43,   52,   45,   33,   47,   35,   49,   50,   16,
     52,   36,   37,   38,   39,   57,   58,    9,   10,   11,
     12,   95,   14,   34,   16,    2,   18,   19,   53,   54,
     55,   56,   24,   21,   59,   46,   28,   29,   30,   43,
     32,   48,   34,   63,   64,   37,   50,   34,   40,   41,
     42,   43,   33,   45,   35,   47,   44,   49,   50,   46,
     52,   36,   37,   38,   39,   57,   58,    9,   10,   11,
     12,   34,   14,   33,   16,   35,   18,   19,   53,   54,
     55,   56,   24,   46,    7,    8,   28,   29,   30,   43,
     32,  103,   34,   34,   33,   37,   35,   51,   40,   41,
     42,   43,   95,   45,   99,   47,   64,   49,   50,   81,
     52,   15,   81,   81,    7,   57,   58,   65,   66,   67,
     68,   70,   70,   71,   95,   73,   74,   75,   77,   78,
      9,   80,   80,   12,   72,   83,   84,   16,   76,   43,
     95,   89,   90,   91,   82,   93,   94,   13,   65,   66,
     67,   68,    9,   70,   71,   12,   73,   74,   75,   16,
     13,   16,   16,   80,  102,   72,   83,   84,   16,   48,
     16,   16,   89,   90,   91,   82,   93,   94,   85,   86,
     87,   65,   14,   67,   68,   16,   70,   71,   32,   73,
     74,   75,   43,   65,   32,   67,   80,   21,   70,   83,
     84,   73,   74,   75,   34,   89,   90,   91,   80,   93,
     94,   83,   84,   26,   16,   16,   49,   89,   90,   91,
     44,   93,   94,   36,   37,   38,   39,   51,   49,   65,
     16,   67,  104,  105,   70,   51,    1,   73,   74,   75,
     53,   54,   55,   56,   80,   51,   15,   83,   84,    1,
     16,   35,  108,   89,   90,   91,  108,   93,   94,   22,
     25,   13,   65,  108,   67,   17,   31,   70,  104,  105,
     73,   74,   75,   25,   77,  108,  108,   80,  108,   31,
     83,   84,   34,  108,  108,  108,   89,   90,   91,  108,
     93,   94,  108,  108,   46,   65,  108,   67,  108,  108,
     70,  108,  108,   73,   74,   75,  108,  108,  108,  108,
     80,  108,   72,   83,   84,  108,  108,  108,  108,   89,
     90,   91,   82,   93,   94,   85,   86,   87,   65,  108,
     67,  101,  108,   70,  108,  108,   73,   74,   75,  108,
    108,  108,  108,   80,  108,   72,   83,   84,  108,  108,
    108,  108,   89,   90,   91,   82,   93,   94,   85,   86,
     87,   65,  108,   67,  101,  108,   70,  108,  108,   73,
     74,   75,  108,  108,  108,  108,   80,  108,  108,   83,
     84,    1,  108,  108,  108,   89,   90,   91,  108,   93,
     94,  108,  108,   13,   65,  108,   67,  108,  108,   70,
    108,  105,   73,   74,   75,   25,  108,  108,  108,   80,
    108,   31,   83,   84,    1,  108,  108,  108,   89,   90,
     91,  108,   93,   94,  108,  108,   13,   65,  108,   67,
    101,  108,   70,  108,  108,   73,   74,   75,   25,   77,
    108,  108,   80,  108,   31,   83,   84,    1,  108,  108,
    108,   89,   90,   91,  108,   93,   94,  108,  108,   13,
     65,  108,   67,  108,  108,   70,  108,  108,   73,   74,
     75,   25,  108,  108,  108,   80,  108,   31,   83,   84,
    108,  108,  108,  108,   89,   90,   91,    9,   93,   94,
     12,  108,  108,   65,   16,   67,  108,    9,   70,  108,
     12,   73,   74,   75,   16,   65,  108,   67,   80,  108,
     70,   83,   84,   73,   74,   75,  108,   89,   90,   91,
     80,   93,   94,   83,   84,    9,   48,  108,   12,   89,
     90,   91,   16,   93,   94,   65,   48,   67,  108,  108,
     70,   25,  108,   73,   74,   75,  108,   31,  108,  108,
     80,  108,  108,   83,   84,  108,  108,  108,  108,   89,
     90,   91,  108,   93,   94,  108,  108,   65,  108,   67,
    108,  108,   70,  108,  108,   73,   74,   75,  108,   65,
    108,   67,   80,  108,   70,   83,   84,   73,   74,   75,
    108,   89,   90,   91,   80,   93,   94,   83,   84,  108,
    108,  108,  108,   89,   90,   91,  108,   93,   94,   65,
    108,   67,  108,  108,   70,  108,  108,   73,   74,   75,
    108,  108,  108,  108,   80,  108,  108,   83,   84,  108,
    108,  108,  108,   89,   90,   91,  108,   93,   94,  108,
    108,   65,  108,   67,  108,  108,   70,  108,  108,   73,
     74,   75,  108,   65,  108,   67,   80,  108,   70,   83,
     84,   73,   74,   75,  108,   89,   90,   91,   80,   93,
     94,   83,   84,  108,  108,  108,  108,   89,   90,   91,
    108,   93,   94,   65,  108,   67,  108,  108,   70,  108,
    108,   73,   74,   75,  108,  108,  108,  108,   80,  108,
    108,   83,   84,  108,  108,  108,  108,   89,   90,   91,
    108,   93,   94,  108,  108,   65,  108,   67,  108,  108,
     70,  108,  108,   73,   74,   75,  108,   65,  108,   67,
     80,  108,   70,   83,   84,   73,   74,   75,  108,   89,
     90,   91,   80,   93,   94,   83,   84,  108,  108,  108,
    108,   89,   90,   91,  108,   93,   94,   65,  108,   67,
    108,  108,   70,  108,  108,   73,   74,   75,  108,  108,
    108,  108,   80,  108,  108,   83,   84,  108,  108,  108,
    108,   89,   90,   91,  108,   93,   94,  108,  108,   65,
    108,   67,  108,  108,   70,  108,  108,   73,   74,   75,
    108,   65,  108,   67,   80,  108,   70,   83,   84,   73,
     74,   75,  108,   89,   90,   91,   80,   93,   94,   83,
     84,  108,  108,  108,  108,   89,   90,   91,  108,   93,
     94,   65,  108,   67,  108,  108,   70,  108,  108,   73,
     74,   75,  108,  108,  108,  108,   80,  108,  108,   83,
     84,  108,  108,  108,  108,   89,   90,   91,  108,   93,
     94,  108,  108,   65,  108,   67,  108,  108,   70,  108,
    108,   73,   74,   75,  108,   65,  108,   67,   80,  108,
     70,   83,   84,   73,   74,   75,  108,   89,   90,   91,
     80,   93,   94,   83,   84,  108,  108,  108,  108,   89,
     90,   91,  108,   93,   94,   65,  108,   67,  108,  108,
     70,  108,  108,   73,   74,   75,  108,  108,  108,  108,
     80,  108,  108,   83,   84,  108,  108,  108,  108,   89,
     90,   91,  108,   93,   94,  108,  108,   65,  108,   67,
    108,  108,   70,  108,  108,   73,   74,   75,  108,   65,
    108,   67,   80,  108,   70,   83,   84,   73,   74,   75,
    108,   89,   90,   91,   80,   93,   94,   83,   84,  108,
    108,  108,  108,   89,   90,   91,  108,   93,   94,   65,
    108,   67,  108,  108,   70,  108,  108,   73,   74,   75,
    108,  108,  108,  108,   80,  108,  108,   83,   84,  108,
    108,  108,  108,   89,   90,   91,  108,   93,   94,  108,
    108,   65,  108,   67,  108,  108,   70,  108,  108,   73,
     74,   75,  108,   65,  108,   67,   80,  108,   70,   83,
     84,   73,   74,   75,  108,   89,   90,   91,   80,   93,
     94,   83,   84,  108,  108,  108,  108,   89,   90,   91,
    108,   93,   94,   65,  108,   67,  108,  108,   70,  108,
    108,   73,   74,   75,  108,  108,  108,  108,   80,  108,
    108,   83,   84,  108,  108,  108,  108,   89,   90,   91,
    108,   93,   94,  108,  108,   65,  108,   67,  108,  108,
     70,  108,  108,   73,   74,   75,  108,   65,  108,   67,
     80,  108,   70,   83,   84,   73,   74,   75,  108,   89,
     90,   91,   80,   93,   94,   83,   84,  108,  108,  108,
    108,   89,   90,   91,  108,   93,   94,    3,   20,  108,
    108,  108,  108,    9,   10,   11,   12,  108,   14,  108,
    108,  108,   18,   19,   36,   37,   38,   39,   24,  108,
    108,  108,   28,   29,   30,  108,  108,   23,  108,   25,
    108,   53,   54,   55,   56,   31,  108,  108,  108,  108,
     36,   37,   38,   39,  108,  108,  108,  108,  108,  108,
    108,  108,   58,   59,  108,  108,    3,   53,   54,   55,
     56,  108,    9,   10,   11,   12,  108,   14,  108,  108,
    108,   18,   19,  108,  108,  108,  108,   24,  108,   25,
    108,   28,   29,   30,  108,   31,  108,  108,  108,  108,
     36,   37,   38,   39,  108,  108,  108,  108,  108,  108,
    108,  108,  108,  108,  108,  108,  108,   53,   54,   55,
     56,   58,   59,  108,  108,    3,    4,    5,    6,  108,
    108,    9,   10,   11,   12,  108,  108,  108,  108,  108,
     18,   19,  108,  108,  108,  108,   24,  108,  108,  108,
     28,   29,   30,   65,  108,   67,  108,  108,   70,  108,
    108,   73,   74,  108,  108,  108,  108,  108,   80,  108,
    108,  108,  108,  108,  108,  108,   88,   89,   90,   91,
    108,   93,   94,  108,  108,  108,  108,  108,   65,  108,
     67,  108,  108,   70,  108,  108,   73,   74,  108,  108,
     65,  108,   67,   80,  108,   70,  108,  108,   73,   74,
    108,   88,   89,   90,   91,   80,   93,   94,  108,  108,
    108,  108,  108,  108,   89,   90,   91,  108,   93,   94,
    108,  108,  108,  108,   65,  108,   67,  108,  108,   70,
    108,  108,   73,   74,  108,  108,  108,  108,  108,   80,
    108,  108,  108,  108,  108,  108,  108,  108,   89,   90,
     91,  108,   93,   94,  108,  108,   65,  108,   67,  108,
    108,   70,  108,  108,   73,   74,  108,  108,   65,  108,
     67,   80,  108,   70,  108,  108,   73,   74,  108,  108,
     89,   90,   91,   80,   93,   94,  108,  108,  108,  108,
    108,  108,   89,   90,   91,  108,   93,   94,   65,  108,
     67,  108,  108,   70,  108,  108,   73,   74,  108,  108,
    108,  108,  108,   80,  108,  108,  108,  108,  108,  108,
    108,  108,   89,   90,   91,  108,   93,   94,  108,  108,
     65,  108,   67,  108,  108,   70,  108,  108,   73,   74,
    108,  108,   65,  108,   67,   80,  108,   70,  108,  108,
     73,   74,  108,  108,   89,   90,   91,   80,   93,   94,
    108,  108,    2,  108,  108,  108,   89,   90,   91,    9,
     93,   94,   12,    2,  108,   15,   16,   17,  108,  108,
      9,   21,  108,   12,  108,  108,    2,   16,   17,  108,
    108,    9,   21,    9,   12,  108,   12,  108,   16,   15,
     16,   17,  108,   43,    2,   21,   46,   25,   48,   27,
     50,  108,  108,   31,   43,  108,  108,   46,  108,   48,
    108,   50,   51,  108,  108,  108,  108,   43,  108,  108,
     46,  108,   48,  108,   50,    2,   34,  108,   36,   37,
     38,   39,    9,  108,  108,   12,  108,  108,   46,   16,
     17,  108,    2,  108,   21,   53,   54,   55,   56,    9,
    108,  108,   12,  108,   13,  108,   16,   17,  108,  108,
    108,   21,  108,  108,  108,  108,   43,  108,  108,   46,
    108,   48,  108,   50,  108,  108,  108,   36,   37,   38,
     39,  108,  108,   43,  108,   13,   46,  108,   48,  108,
     50,  108,  108,  108,   53,   54,   55,   56,   36,   37,
     38,   39,   35,   36,   37,   38,   39,  108,   36,   37,
     38,   39,   13,   51,    2,   53,   54,   55,   56,   13,
     53,   54,   55,   56,  108,   53,   54,   55,   56,  108,
    108,  108,  108,  108,  108,   36,   37,   38,   39,  108,
    108,  108,   36,   37,   38,   39,  108,  108,   36,   37,
     38,   39,   53,   54,   55,   56,   13,  108,  108,   53,
     54,   55,   56,  108,  108,   53,   54,   55,   56,    9,
    108,  108,   12,  108,  108,  108,   16,   17,  108,   36,
     37,   38,   39,  108,  108,  108,  108,  108,  108,  108,
    108,  108,  108,  108,  108,  108,   53,   54,   55,   56,
    108,  108,  108,   43,  108,  108,   46,  108,   48,  108,
     50,
);
    const YY_SHIFT_USE_DFLT = -29;
    const YY_SHIFT_MAX = 234;
    public static $yy_shift_ofst = array(
    -29,   98,   98,  148,  198,  198,  248,  148,  148,  198,
    148,  248,   -2,   48,  298,  148,  148,  148,  298,  148,
    148,  148,  148,  148,  148,  148,  148,  148,  148,  148,
    348,  148,  148,  148,  148,  398,  148,  148,  148,  448,
    498,  498,  498,  498,  498,  498,  498,  498, 1574, 1624,
   1624,  147, 1564,  688,  285,  140,  675, 1623, 1548,  627,
   2021, 2047, 2042, 2052,  415, 2079, 2086, 2092, 2123,  465,
    465,  465,  465,  465,  465,  465,  465,  465,  465,  465,
    465,  465,  465,  465,  465,  465,  465, 1952,  956,  136,
     87,  675,  675,  140,  140,  150, 1682, 1930,  561,   59,
    820,  853,  886,  337,  337,  103,  250,  273,  250,  406,
    314,  156,  215,  215,  203,  382,  402,  250,   19,   19,
     19,   19,   19,   19,   19,   19,   17,   17,   78,   19,
    -29,  -29, 1941, 1954, 2003, 2020, 2140,   49,  918,  583,
    236,  250,  250,  308,  250,  390,  250,  390,  250,  368,
    368,  250,  250,  250,  250,  368,  153,  368,  368,  368,
    436,  368,  436,  368,  250,  250,  250,  250,   19,  463,
     19,   19,  463,   19,  499,   17,   17,   17,  -29,  -29,
    -29,  -29,  -29,  -29, 1972,   11,  100,  190,  240,  928,
    -28,  191,  342,  616,  362,  517,  104,  433,  452,  429,
    453,  477,  411,  459,   41,  486,  480,  501,  536,  547,
    574,  587,  585,  586,  592,  594,  595,  608,  609,  589,
    596,  602,  610,  638,  499,  639,  607,  619,  654,  624,
    634,  674,  671,  656,  677,
);
    const YY_REDUCE_USE_DFLT = -88;
    const YY_REDUCE_MAX = 183;
    public static $yy_reduce_ofst = array(
    -59,  492,  523,  556,  568,  604,  637,  670,  703,  736,
    769,  802,  835,  868,  880,  910,  942,  954,  984, 1016,
   1028, 1058, 1090, 1102, 1132, 1164, 1176, 1206, 1238, 1250,
   1280, 1312, 1324, 1354, 1386, 1398, 1428, 1460, 1472, 1648,
   1683, 1695, 1729, 1761, 1773, 1803, 1835, 1847,  533,  680,
    713,  -69,   77,   99,  281,  491,  502,   29,  -34,  -34,
    -34,  -34,  -34,  -34,  -34,  -34,  -34,  -34,  -34,  -34,
    -34,  -34,  -34,  -34,  -34,  -34,  -34,  -34,  -34,  -34,
    -34,  -34,  -34,  -34,  -34,  -34,  -34,  239,  299,  -12,
    175,  222,  231,  143,  172,  318,    3,   34,   26,  -51,
    194,  194,  194,   73,   26,  275,  164,  272,  220,  320,
    242,  275,  -87,  287,  194,  194,  194,  341,  323,  194,
    194,  194,  194,  194,  194,  194,  275,  335,  194,  194,
    420,  194,  129,  129,  129,  129,  129,  183,  -14,  129,
    129,  151,  151,  189,  151,  344,  151,  356,  151,  187,
    187,  151,  151,  151,  151,  187,  225,  187,  187,  187,
    270,  187,  366,  187,  151,  151,  151,  151,  313,  428,
    313,  313,  428,  313,  447,  445,  445,  445,  482,  468,
    471,  472,  469,  485,
);
    public static $yyExpectedTokens = array(
         array(),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(2, 9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 39, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 51, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 21, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(9, 10, 11, 12, 14, 16, 18, 19, 24, 28, 29, 30, 32, 34, 37, 40, 41, 42, 43, 45, 47, 49, 50, 52, 57, 58, ),
         array(23, 25, 31, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(25, 31, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(25, 31, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(14, 16, 47, 49, 52, ),
         array(3, 9, 10, 11, 12, 14, 18, 19, 24, 28, 29, 30, 58, 59, ),
         array(1, 13, 17, 25, 31, 34, 46, ),
         array(14, 16, 49, 52, ),
         array(14, 34, 52, ),
         array(1, 25, 31, ),
         array(3, 9, 10, 11, 12, 14, 18, 19, 24, 28, 29, 30, 58, 59, ),
         array(20, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(26, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(13, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(35, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 51, 53, 54, 55, 56, ),
         array(13, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, 59, ),
         array(13, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(13, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(2, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(13, 36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(36, 37, 38, 39, 53, 54, 55, 56, ),
         array(9, 12, 16, 25, 27, 31, ),
         array(9, 12, 16, 25, 31, ),
         array(17, 43, 50, ),
         array(15, 17, 46, ),
         array(1, 25, 31, ),
         array(1, 25, 31, ),
         array(14, 34, 52, ),
         array(14, 34, 52, ),
         array(1, 2, ),
         array(3, 4, 5, 6, 9, 10, 11, 12, 18, 19, 24, 28, 29, 30, ),
         array(2, 9, 12, 15, 16, 17, 21, 43, 46, 48, 50, ),
         array(9, 12, 16, 48, ),
         array(12, 14, 16, 52, ),
         array(1, 13, 25, 31, ),
         array(1, 13, 25, 31, ),
         array(1, 13, 25, 31, ),
         array(9, 12, 16, ),
         array(9, 12, 16, ),
         array(15, 17, 46, ),
         array(25, 31, ),
         array(14, 52, ),
         array(25, 31, ),
         array(25, 31, ),
         array(1, 17, ),
         array(17, 46, ),
         array(14, 16, ),
         array(14, 16, ),
         array(1, 51, ),
         array(1, 2, ),
         array(1, 27, ),
         array(25, 31, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(1, ),
         array(17, ),
         array(17, ),
         array(1, ),
         array(1, ),
         array(),
         array(),
         array(2, 9, 12, 16, 17, 21, 43, 46, 48, 50, 51, ),
         array(2, 9, 12, 15, 16, 17, 21, 43, 46, 48, 50, ),
         array(2, 9, 12, 16, 17, 21, 43, 46, 48, 50, ),
         array(2, 9, 12, 16, 17, 21, 43, 46, 48, 50, ),
         array(9, 12, 16, 17, 43, 46, 48, 50, ),
         array(12, 14, 16, 32, 52, ),
         array(9, 12, 16, 48, ),
         array(9, 12, 16, ),
         array(15, 43, 50, ),
         array(25, 31, ),
         array(25, 31, ),
         array(15, 21, ),
         array(25, 31, ),
         array(14, 52, ),
         array(25, 31, ),
         array(14, 52, ),
         array(25, 31, ),
         array(43, 50, ),
         array(43, 50, ),
         array(25, 31, ),
         array(25, 31, ),
         array(25, 31, ),
         array(25, 31, ),
         array(43, 50, ),
         array(12, 34, ),
         array(43, 50, ),
         array(43, 50, ),
         array(43, 50, ),
         array(43, 50, ),
         array(43, 50, ),
         array(43, 50, ),
         array(43, 50, ),
         array(25, 31, ),
         array(25, 31, ),
         array(25, 31, ),
         array(25, 31, ),
         array(1, ),
         array(2, ),
         array(1, ),
         array(1, ),
         array(2, ),
         array(1, ),
         array(34, ),
         array(17, ),
         array(17, ),
         array(17, ),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(2, 34, 36, 37, 38, 39, 46, 53, 54, 55, 56, ),
         array(13, 20, 22, 25, 31, 33, 35, 43, ),
         array(13, 15, 25, 31, 34, 46, ),
         array(13, 21, 25, 31, 44, ),
         array(13, 21, 25, 31, 44, ),
         array(9, 12, 16, 48, ),
         array(34, 43, 46, 51, ),
         array(27, 34, 46, ),
         array(21, 44, 59, ),
         array(21, 44, 51, ),
         array(6, 8, ),
         array(7, 8, ),
         array(20, 33, ),
         array(16, 48, ),
         array(21, 44, ),
         array(34, 46, ),
         array(34, 46, ),
         array(34, 46, ),
         array(33, 35, ),
         array(33, 35, ),
         array(33, 51, ),
         array(43, 51, ),
         array(33, 35, ),
         array(33, 35, ),
         array(15, 43, ),
         array(7, ),
         array(13, ),
         array(13, ),
         array(16, ),
         array(16, ),
         array(16, ),
         array(16, ),
         array(16, ),
         array(14, ),
         array(16, ),
         array(43, ),
         array(32, ),
         array(32, ),
         array(34, ),
         array(16, ),
         array(34, ),
         array(16, ),
         array(49, ),
         array(49, ),
         array(16, ),
         array(51, ),
         array(51, ),
         array(16, ),
         array(15, ),
         array(35, ),
         array(22, ),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
         array(),
);
    public static $yy_default = array(
    342,  523,  523,  523,  508,  508,  523,  485,  485,  523,
    485,  523,  523,  523,  523,  523,  523,  523,  523,  523,
    523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
    523,  523,  523,  523,  523,  523,  523,  523,  523,  523,
    523,  523,  523,  523,  523,  523,  523,  523,  382,  361,
    382,  523,  523,  424,  523,  523,  382,  523,  523,  387,
    523,  523,  523,  355,  523,  523,  523,  523,  523,  366,
    484,  405,  411,  483,  509,  511,  510,  410,  412,  409,
    413,  389,  393,  394,  384,  387,  355,  382,  382,  498,
    440,  382,  382,  523,  523,  373,  332,  439,  450,  523,
    396,  396,  396,  450,  450,  440,  382,  523,  382,  382,
    376,  440,  523,  523,  396,  396,  396,  363,  378,  396,
    403,  415,  416,  417,  404,  408,  440,  495,  415,  402,
    340,  492,  439,  439,  439,  439,  439,  523,  452,  450,
    466,  352,  362,  523,  365,  523,  370,  523,  371,  447,
    448,  356,  358,  359,  360,  476,  450,  475,  478,  477,
    443,  444,  445,  446,  372,  368,  369,  364,  374,  486,
    377,  379,  487,  433,  450,  472,  499,  496,  340,  491,
    491,  491,  450,  450,  424,  420,  424,  414,  414,  451,
    424,  424,  414,  414,  338,  523,  523,  523,  414,  424,
    434,  523,  523,  523,  523,  420,  523,  523,  420,  523,
    523,  523,  523,  523,  523,  523,  523,  523,  523,  420,
    422,  523,  497,  523,  466,  523,  523,  523,  523,  523,
    429,  523,  523,  523,  390,  333,  334,  335,  336,  337,
    339,  341,  343,  344,  345,  346,  347,  348,  349,  351,
    380,  381,  468,  469,  470,  490,  375,  488,  489,  418,
    427,  428,  437,  438,  449,  453,  454,  455,  397,  398,
    399,  400,  401,  419,  421,  423,  425,  429,  430,  431,
    406,  407,  432,  435,  436,  463,  461,  500,  501,  502,
    503,  441,  442,  474,  467,  482,  350,  473,  519,  520,
    512,  513,  514,  517,  516,  518,  521,  522,  515,  505,
    507,  506,  504,  479,  464,  462,  460,  457,  458,  459,
    465,  480,  481,  426,  456,  494,  471,  466,  383,  367,
    391,  395,
);
    const YYNOCODE = 109;
    const YYSTACKDEPTH = 500;
    const YYNSTATE = 332;
    const YYNRULE = 191;
    const YYERRORSYMBOL = 60;
    const YYERRSYMDT = 'yy0';
    const YYFALLBACK = 0;
    public static $yyFallback = array(
    );
    public function Trace($TraceFILE, $zTracePrompt)
    {
        if (!$TraceFILE) {
            $zTracePrompt = 0;
        } elseif (!$zTracePrompt) {
            $TraceFILE = 0;
        }
        $this->yyTraceFILE = $TraceFILE;
        $this->yyTracePrompt = $zTracePrompt;
    }

    public function PrintTrace()
    {
        $this->yyTraceFILE = fopen('php://output', 'w');
        $this->yyTracePrompt = '<br>';
    }

    public $yyTraceFILE;
    public $yyTracePrompt;
    public $yyidx;                    /* Index of top element in stack */
    public $yyerrcnt;                 /* Shifts left before out of the error */
    public $yystack = array();  /* The parser's stack */

    public $yyTokenName = array(
  '$',             'VERT',          'COLON',         'TEXT',        
  'STRIPON',       'STRIPOFF',      'LITERALSTART',  'LITERALEND',  
  'LITERAL',       'SIMPELOUTPUT',  'SIMPLETAG',     'SMARTYBLOCKCHILDPARENT',
  'LDEL',          'RDEL',          'DOLLARID',      'EQUAL',       
  'ID',            'PTR',           'LDELIF',        'LDELFOR',     
  'SEMICOLON',     'INCDEC',        'TO',            'STEP',        
  'LDELFOREACH',   'SPACE',         'AS',            'APTR',        
  'LDELSETFILTER',  'CLOSETAG',      'LDELSLASH',     'ATTR',        
  'INTEGER',       'COMMA',         'OPENP',         'CLOSEP',      
  'MATH',          'UNIMATH',       'ISIN',          'QMARK',       
  'NOT',           'TYPECAST',      'HEX',           'DOT',         
  'INSTANCEOF',    'SINGLEQUOTESTRING',  'DOUBLECOLON',   'NAMESPACE',   
  'AT',            'HATCH',         'OPENB',         'CLOSEB',      
  'DOLLAR',        'LOGOP',         'SLOGOP',        'TLOGOP',      
  'SINGLECOND',    'ARRAYOPEN',     'QUOTE',         'BACKTICK',    
  'error',         'start',         'template',      'literal_e2',  
  'literal_e1',    'smartytag',     'tagbody',       'tag',         
  'outattr',       'eqoutattr',     'varindexed',    'output',      
  'attributes',    'variable',      'value',         'expr',        
  'modifierlist',  'statement',     'statements',    'foraction',   
  'varvar',        'modparameters',  'attribute',     'nullcoalescing',
  'ternary',       'tlop',          'lop',           'scond',       
  'array',         'function',      'ns1',           'doublequoted_with_quotes',
  'static_class_access',  'arraydef',      'object',        'arrayindex',  
  'indexdef',      'varvarele',     'objectchain',   'objectelement',
  'method',        'params',        'modifier',      'modparameter',
  'arrayelements',  'arrayelement',  'doublequoted',  'doublequotedcontent',
    );

    public static $yyRuleName = array(
  'start ::= template',
  'template ::= template TEXT',
  'template ::= template STRIPON',
  'template ::= template STRIPOFF',
  'template ::= template LITERALSTART literal_e2 LITERALEND',
  'literal_e2 ::= literal_e1 LITERALSTART literal_e1 LITERALEND',
  'literal_e2 ::= literal_e1',
  'literal_e1 ::= literal_e1 LITERAL',
  'literal_e1 ::=',
  'template ::= template smartytag',
  'template ::=',
  'smartytag ::= SIMPELOUTPUT',
  'smartytag ::= SIMPLETAG',
  'smartytag ::= SMARTYBLOCKCHILDPARENT',
  'smartytag ::= LDEL tagbody RDEL',
  'smartytag ::= tag RDEL',
  'tagbody ::= outattr',
  'tagbody ::= DOLLARID eqoutattr',
  'tagbody ::= varindexed eqoutattr',
  'eqoutattr ::= EQUAL outattr',
  'outattr ::= output attributes',
  'output ::= variable',
  'output ::= value',
  'output ::= expr',
  'tag ::= LDEL ID attributes',
  'tag ::= LDEL ID',
  'tag ::= LDEL ID modifierlist attributes',
  'tag ::= LDEL ID PTR ID attributes',
  'tag ::= LDEL ID PTR ID modifierlist attributes',
  'tag ::= LDELIF expr',
  'tag ::= LDELIF expr attributes',
  'tag ::= LDELIF statement',
  'tag ::= LDELIF statement attributes',
  'tag ::= LDELFOR statements SEMICOLON expr SEMICOLON varindexed foraction attributes',
  'foraction ::= EQUAL expr',
  'foraction ::= INCDEC',
  'tag ::= LDELFOR statement TO expr attributes',
  'tag ::= LDELFOR statement TO expr STEP expr attributes',
  'tag ::= LDELFOREACH SPACE expr AS varvar attributes',
  'tag ::= LDELFOREACH SPACE expr AS varvar APTR varvar attributes',
  'tag ::= LDELFOREACH attributes',
  'tag ::= LDELSETFILTER ID modparameters',
  'tag ::= LDELSETFILTER ID modparameters modifierlist',
  'smartytag ::= CLOSETAG',
  'tag ::= LDELSLASH ID',
  'tag ::= LDELSLASH ID modifierlist',
  'tag ::= LDELSLASH ID PTR ID',
  'tag ::= LDELSLASH ID PTR ID modifierlist',
  'attributes ::= attributes attribute',
  'attributes ::= attribute',
  'attributes ::=',
  'attribute ::= SPACE ID EQUAL ID',
  'attribute ::= ATTR expr',
  'attribute ::= ATTR value',
  'attribute ::= SPACE ID',
  'attribute ::= SPACE expr',
  'attribute ::= SPACE value',
  'attribute ::= SPACE INTEGER EQUAL expr',
  'statements ::= statement',
  'statements ::= statements COMMA statement',
  'statement ::= DOLLARID EQUAL INTEGER',
  'statement ::= DOLLARID EQUAL expr',
  'statement ::= varindexed EQUAL expr',
  'statement ::= OPENP statement CLOSEP',
  'expr ::= value',
  'expr ::= nullcoalescing',
  'expr ::= ternary',
  'expr ::= INCDEC DOLLARID',
  'expr ::= DOLLARID INCDEC',
  'expr ::= DOLLARID COLON ID',
  'expr ::= expr MATH value',
  'expr ::= expr UNIMATH value',
  'expr ::= expr tlop value',
  'expr ::= expr lop expr',
  'expr ::= expr scond',
  'expr ::= expr ISIN array',
  'expr ::= expr ISIN value',
  'nullcoalescing ::= expr QMARK QMARK expr',
  'ternary ::= expr QMARK DOLLARID COLON expr',
  'ternary ::= expr QMARK value COLON expr',
  'ternary ::= expr QMARK expr COLON expr',
  'ternary ::= expr QMARK COLON expr',
  'value ::= variable',
  'value ::= UNIMATH value',
  'value ::= NOT value',
  'value ::= TYPECAST value',
  'value ::= variable INCDEC',
  'value ::= HEX',
  'value ::= INTEGER',
  'value ::= INTEGER DOT INTEGER',
  'value ::= INTEGER DOT',
  'value ::= DOT INTEGER',
  'value ::= ID',
  'value ::= function',
  'value ::= OPENP expr CLOSEP',
  'value ::= variable INSTANCEOF ns1',
  'value ::= variable INSTANCEOF variable',
  'value ::= SINGLEQUOTESTRING',
  'value ::= doublequoted_with_quotes',
  'value ::= varindexed DOUBLECOLON static_class_access',
  'value ::= smartytag',
  'value ::= value modifierlist',
  'value ::= NAMESPACE',
  'value ::= arraydef',
  'value ::= ns1 DOUBLECOLON static_class_access',
  'ns1 ::= ID',
  'ns1 ::= NAMESPACE',
  'variable ::= DOLLARID',
  'variable ::= varindexed',
  'variable ::= varvar AT ID',
  'variable ::= object',
  'variable ::= HATCH ID HATCH',
  'variable ::= HATCH ID HATCH arrayindex',
  'variable ::= HATCH variable HATCH',
  'variable ::= HATCH variable HATCH arrayindex',
  'varindexed ::= DOLLARID arrayindex',
  'varindexed ::= varvar arrayindex',
  'arrayindex ::= arrayindex indexdef',
  'arrayindex ::=',
  'indexdef ::= DOT DOLLARID',
  'indexdef ::= DOT varvar',
  'indexdef ::= DOT varvar AT ID',
  'indexdef ::= DOT ID',
  'indexdef ::= DOT INTEGER',
  'indexdef ::= DOT LDEL expr RDEL',
  'indexdef ::= OPENB ID CLOSEB',
  'indexdef ::= OPENB ID DOT ID CLOSEB',
  'indexdef ::= OPENB SINGLEQUOTESTRING CLOSEB',
  'indexdef ::= OPENB INTEGER CLOSEB',
  'indexdef ::= OPENB DOLLARID CLOSEB',
  'indexdef ::= OPENB variable CLOSEB',
  'indexdef ::= OPENB value CLOSEB',
  'indexdef ::= OPENB expr CLOSEB',
  'indexdef ::= OPENB CLOSEB',
  'varvar ::= DOLLARID',
  'varvar ::= DOLLAR',
  'varvar ::= varvar varvarele',
  'varvarele ::= ID',
  'varvarele ::= SIMPELOUTPUT',
  'varvarele ::= LDEL expr RDEL',
  'object ::= varindexed objectchain',
  'objectchain ::= objectelement',
  'objectchain ::= objectchain objectelement',
  'objectelement ::= PTR ID arrayindex',
  'objectelement ::= PTR varvar arrayindex',
  'objectelement ::= PTR LDEL expr RDEL arrayindex',
  'objectelement ::= PTR ID LDEL expr RDEL arrayindex',
  'objectelement ::= PTR method',
  'function ::= ns1 OPENP params CLOSEP',
  'method ::= ID OPENP params CLOSEP',
  'method ::= DOLLARID OPENP params CLOSEP',
  'params ::= params COMMA expr',
  'params ::= expr',
  'params ::=',
  'modifierlist ::= modifierlist modifier modparameters',
  'modifierlist ::= modifier modparameters',
  'modifier ::= VERT AT ID',
  'modifier ::= VERT ID',
  'modparameters ::= modparameters modparameter',
  'modparameters ::=',
  'modparameter ::= COLON value',
  'modparameter ::= COLON UNIMATH value',
  'modparameter ::= COLON array',
  'static_class_access ::= method',
  'static_class_access ::= method objectchain',
  'static_class_access ::= ID',
  'static_class_access ::= DOLLARID arrayindex',
  'static_class_access ::= DOLLARID arrayindex objectchain',
  'lop ::= LOGOP',
  'lop ::= SLOGOP',
  'tlop ::= TLOGOP',
  'scond ::= SINGLECOND',
  'arraydef ::= OPENB arrayelements CLOSEB',
  'arraydef ::= ARRAYOPEN arrayelements CLOSEP',
  'arrayelements ::= arrayelement',
  'arrayelements ::= arrayelements COMMA arrayelement',
  'arrayelements ::=',
  'arrayelement ::= value APTR expr',
  'arrayelement ::= ID APTR expr',
  'arrayelement ::= expr',
  'doublequoted_with_quotes ::= QUOTE QUOTE',
  'doublequoted_with_quotes ::= QUOTE doublequoted QUOTE',
  'doublequoted ::= doublequoted doublequotedcontent',
  'doublequoted ::= doublequotedcontent',
  'doublequotedcontent ::= BACKTICK variable BACKTICK',
  'doublequotedcontent ::= BACKTICK expr BACKTICK',
  'doublequotedcontent ::= DOLLARID',
  'doublequotedcontent ::= LDEL variable RDEL',
  'doublequotedcontent ::= LDEL expr RDEL',
  'doublequotedcontent ::= smartytag',
  'doublequotedcontent ::= TEXT',
    );

    public function tokenName($tokenType)
    {
        if ($tokenType === 0) {
            return 'End of Input';
        }
        if ($tokenType > 0 && $tokenType < count($this->yyTokenName)) {
            return $this->yyTokenName[$tokenType];
        } else {
            return 'Unknown';
        }
    }

    public static function yy_destructor($yymajor, $yypminor)
    {
        switch ($yymajor) {
            default:  break;   /* If no destructor action specified: do nothing */
        }
    }

    public function yy_pop_parser_stack()
    {
        if (empty($this->yystack)) {
            return;
        }
        $yytos = array_pop($this->yystack);
        if ($this->yyTraceFILE && $this->yyidx >= 0) {
            fwrite($this->yyTraceFILE,
                $this->yyTracePrompt . 'Popping ' . $this->yyTokenName[$yytos->major] .
                    "\n");
        }
        $yymajor = $yytos->major;
        self::yy_destructor($yymajor, $yytos->minor);
        $this->yyidx--;

        return $yymajor;
    }

    public function __destruct()
    {
        while ($this->yystack !== Array()) {
            $this->yy_pop_parser_stack();
        }
        if (is_resource($this->yyTraceFILE)) {
            fclose($this->yyTraceFILE);
        }
    }

    public function yy_get_expected_tokens($token)
    {
        static $res3 = array();
        static $res4 = array();
        $state = $this->yystack[$this->yyidx]->stateno;
        $expected = self::$yyExpectedTokens[$state];
        if (isset($res3[$state][$token])) {
            if ($res3[$state][$token]) {
                return $expected;
            }
        } else {
            if ($res3[$state][$token] = in_array($token, self::$yyExpectedTokens[$state], true)) {
                return $expected;
            }
        }
        $stack = $this->yystack;
        $yyidx = $this->yyidx;
        do {
            $yyact = $this->yy_find_shift_action($token);
            if ($yyact >= self::YYNSTATE && $yyact < self::YYNSTATE + self::YYNRULE) {
                // reduce action
                $done = 0;
                do {
                    if ($done++ === 100) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // too much recursion prevents proper detection
                        // so give up
                        return array_unique($expected);
                    }
                    $yyruleno = $yyact - self::YYNSTATE;
                    $this->yyidx -= self::$yyRuleInfo[$yyruleno][1];
                    $nextstate = $this->yy_find_reduce_action(
                        $this->yystack[$this->yyidx]->stateno,
                        self::$yyRuleInfo[$yyruleno][0]);
                    if (isset(self::$yyExpectedTokens[$nextstate])) {
                        $expected = array_merge($expected, self::$yyExpectedTokens[$nextstate]);
                        if (isset($res4[$nextstate][$token])) {
                            if ($res4[$nextstate][$token]) {
                                $this->yyidx = $yyidx;
                                $this->yystack = $stack;
                                return array_unique($expected);
                            }
                        } else {
                            if ($res4[$nextstate][$token] = in_array($token, self::$yyExpectedTokens[$nextstate], true)) {
                                $this->yyidx = $yyidx;
                                $this->yystack = $stack;
                                return array_unique($expected);
                            }
                        }
                    }
                    if ($nextstate < self::YYNSTATE) {
                        // we need to shift a non-terminal
                        $this->yyidx++;
                        $x = (object) ['stateno' => null, 'major' => null, 'minor' => null];
                        $x->stateno = $nextstate;
                        $x->major = self::$yyRuleInfo[$yyruleno][0];
                        $this->yystack[$this->yyidx] = $x;
                        continue 2;
                    } elseif ($nextstate === self::YYNSTATE + self::YYNRULE + 1) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // the last token was just ignored, we can't accept
                        // by ignoring input, this is in essence ignoring a
                        // syntax error!
                        return array_unique($expected);
                    } elseif ($nextstate === self::YY_NO_ACTION) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // input accepted, but not shifted (I guess)
                        return $expected;
                    } else {
                        $yyact = $nextstate;
                    }
                } while (true);
            }
            break;
        } while (true);
        $this->yyidx = $yyidx;
        $this->yystack = $stack;

        return array_unique($expected);
    }

    public function yy_is_expected_token($token)
    {
        static $res = array();
        static $res2 = array();
        if ($token === 0) {
            return true; // 0 is not part of this
        }
        $state = $this->yystack[$this->yyidx]->stateno;
        if (isset($res[$state][$token])) {
            if ($res[$state][$token]) {
                return true;
            }
        } else {
            if ($res[$state][$token] = in_array($token, self::$yyExpectedTokens[$state], true)) {
                return true;
            }
       }
        $stack = $this->yystack;
        $yyidx = $this->yyidx;
        do {
            $yyact = $this->yy_find_shift_action($token);
            if ($yyact >= self::YYNSTATE && $yyact < self::YYNSTATE + self::YYNRULE) {
                // reduce action
                $done = 0;
                do {
                    if ($done++ === 100) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // too much recursion prevents proper detection
                        // so give up
                        return true;
                    }
                    $yyruleno = $yyact - self::YYNSTATE;
                    $this->yyidx -= self::$yyRuleInfo[$yyruleno][1];
                    $nextstate = $this->yy_find_reduce_action(
                        $this->yystack[$this->yyidx]->stateno,
                        self::$yyRuleInfo[$yyruleno][0]);
                    if (isset($res2[$nextstate][$token])) {
                        if ($res2[$nextstate][$token]) {
                            $this->yyidx = $yyidx;
                            $this->yystack = $stack;
                            return true;
                        }
                    } else {
                        if ($res2[$nextstate][$token] = (isset(self::$yyExpectedTokens[$nextstate]) && in_array($token, self::$yyExpectedTokens[$nextstate], true))) {
                            $this->yyidx = $yyidx;
                            $this->yystack = $stack;
                            return true;
                        }
                    }
                    if ($nextstate < self::YYNSTATE) {
                        // we need to shift a non-terminal
                        $this->yyidx++;
                        $x = (object) ['stateno' => null, 'major' => null, 'minor' => null];
                        $x->stateno = $nextstate;
                        $x->major = self::$yyRuleInfo[$yyruleno][0];
                        $this->yystack[$this->yyidx] = $x;
                        continue 2;
                    } elseif ($nextstate === self::YYNSTATE + self::YYNRULE + 1) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        if (!$token) {
                            // end of input: this is valid
                            return true;
                        }
                        // the last token was just ignored, we can't accept
                        // by ignoring input, this is in essence ignoring a
                        // syntax error!
                        return false;
                    } elseif ($nextstate === self::YY_NO_ACTION) {
                        $this->yyidx = $yyidx;
                        $this->yystack = $stack;
                        // input accepted, but not shifted (I guess)
                        return true;
                    } else {
                        $yyact = $nextstate;
                    }
                } while (true);
            }
            break;
        } while (true);
        $this->yyidx = $yyidx;
        $this->yystack = $stack;

        return true;
    }

   public function yy_find_shift_action($iLookAhead)
    {
        $stateno = $this->yystack[$this->yyidx]->stateno;

        /* if ($this->yyidx < 0) return self::YY_NO_ACTION;  */
        if (!isset(self::$yy_shift_ofst[$stateno])) {
            // no shift actions
            return self::$yy_default[$stateno];
        }
        $i = self::$yy_shift_ofst[$stateno];
        if ($i === self::YY_SHIFT_USE_DFLT) {
            return self::$yy_default[$stateno];
        }
        if ($iLookAhead === self::YYNOCODE) {
            return self::YY_NO_ACTION;
        }
        $i += $iLookAhead;
        if ($i < 0 || $i >= self::YY_SZ_ACTTAB ||
              self::$yy_lookahead[$i] != $iLookAhead) {
            if (count(self::$yyFallback) && $iLookAhead < count(self::$yyFallback)
                   && ($iFallback = self::$yyFallback[$iLookAhead]) != 0) {
                if ($this->yyTraceFILE) {
                    fwrite($this->yyTraceFILE, $this->yyTracePrompt . 'FALLBACK ' .
                        $this->yyTokenName[$iLookAhead] . ' => ' .
                        $this->yyTokenName[$iFallback] . "\n");
                }

                return $this->yy_find_shift_action($iFallback);
            }

            return self::$yy_default[$stateno];
        } else {
            return self::$yy_action[$i];
        }
    }

    public function yy_find_reduce_action($stateno, $iLookAhead)
    {
        /* $stateno = $this->yystack[$this->yyidx]->stateno; */

        if (!isset(self::$yy_reduce_ofst[$stateno])) {
            return self::$yy_default[$stateno];
        }
        $i = self::$yy_reduce_ofst[$stateno];
        if ($i === self::YY_REDUCE_USE_DFLT) {
            return self::$yy_default[$stateno];
        }
        if ($iLookAhead === self::YYNOCODE) {
            return self::YY_NO_ACTION;
        }
        $i += $iLookAhead;
        if ($i < 0 || $i >= self::YY_SZ_ACTTAB ||
              self::$yy_lookahead[$i] != $iLookAhead) {
            return self::$yy_default[$stateno];
        } else {
            return self::$yy_action[$i];
        }
    }

    public function yy_shift($yyNewState, $yyMajor, $yypMinor)
    {
        $this->yyidx++;
        if ($this->yyidx >= self::YYSTACKDEPTH) {
            $this->yyidx--;
            if ($this->yyTraceFILE) {
                fprintf($this->yyTraceFILE, "%sStack Overflow!\n", $this->yyTracePrompt);
            }
            while ($this->yyidx >= 0) {
                $this->yy_pop_parser_stack();
            }
// line 232 "src/Parser/TemplateParser.y"

    $this->internalError = true;
    $this->compiler->trigger_template_error('Stack overflow in template parser');

            return;
        }
        $yytos = (object) ['stateno' => null, 'major' => null, 'minor' => null];
        $yytos->stateno = $yyNewState;
        $yytos->major = $yyMajor;
        $yytos->minor = $yypMinor;
        $this->yystack[] = $yytos;
        if ($this->yyTraceFILE && $this->yyidx > 0) {
            fprintf($this->yyTraceFILE, "%sShift %d\n", $this->yyTracePrompt,
                $yyNewState);
            fprintf($this->yyTraceFILE, "%sStack:", $this->yyTracePrompt);
            for ($i = 1; $i <= $this->yyidx; $i++) {
                fprintf($this->yyTraceFILE, " %s",
                    $this->yyTokenName[$this->yystack[$i]->major]);
            }
            fwrite($this->yyTraceFILE,"\n");
        }
    }

    public static $yyRuleInfo = array(
  array( 0 => 61, 1 => 1 ),
  array( 0 => 62, 1 => 2 ),
  array( 0 => 62, 1 => 2 ),
  array( 0 => 62, 1 => 2 ),
  array( 0 => 62, 1 => 4 ),
  array( 0 => 63, 1 => 4 ),
  array( 0 => 63, 1 => 1 ),
  array( 0 => 64, 1 => 2 ),
  array( 0 => 64, 1 => 0 ),
  array( 0 => 62, 1 => 2 ),
  array( 0 => 62, 1 => 0 ),
  array( 0 => 65, 1 => 1 ),
  array( 0 => 65, 1 => 1 ),
  array( 0 => 65, 1 => 1 ),
  array( 0 => 65, 1 => 3 ),
  array( 0 => 65, 1 => 2 ),
  array( 0 => 66, 1 => 1 ),
  array( 0 => 66, 1 => 2 ),
  array( 0 => 66, 1 => 2 ),
  array( 0 => 69, 1 => 2 ),
  array( 0 => 68, 1 => 2 ),
  array( 0 => 71, 1 => 1 ),
  array( 0 => 71, 1 => 1 ),
  array( 0 => 71, 1 => 1 ),
  array( 0 => 67, 1 => 3 ),
  array( 0 => 67, 1 => 2 ),
  array( 0 => 67, 1 => 4 ),
  array( 0 => 67, 1 => 5 ),
  array( 0 => 67, 1 => 6 ),
  array( 0 => 67, 1 => 2 ),
  array( 0 => 67, 1 => 3 ),
  array( 0 => 67, 1 => 2 ),
  array( 0 => 67, 1 => 3 ),
  array( 0 => 67, 1 => 8 ),
  array( 0 => 79, 1 => 2 ),
  array( 0 => 79, 1 => 1 ),
  array( 0 => 67, 1 => 5 ),
  array( 0 => 67, 1 => 7 ),
  array( 0 => 67, 1 => 6 ),
  array( 0 => 67, 1 => 8 ),
  array( 0 => 67, 1 => 2 ),
  array( 0 => 67, 1 => 3 ),
  array( 0 => 67, 1 => 4 ),
  array( 0 => 65, 1 => 1 ),
  array( 0 => 67, 1 => 2 ),
  array( 0 => 67, 1 => 3 ),
  array( 0 => 67, 1 => 4 ),
  array( 0 => 67, 1 => 5 ),
  array( 0 => 72, 1 => 2 ),
  array( 0 => 72, 1 => 1 ),
  array( 0 => 72, 1 => 0 ),
  array( 0 => 82, 1 => 4 ),
  array( 0 => 82, 1 => 2 ),
  array( 0 => 82, 1 => 2 ),
  array( 0 => 82, 1 => 2 ),
  array( 0 => 82, 1 => 2 ),
  array( 0 => 82, 1 => 2 ),
  array( 0 => 82, 1 => 4 ),
  array( 0 => 78, 1 => 1 ),
  array( 0 => 78, 1 => 3 ),
  array( 0 => 77, 1 => 3 ),
  array( 0 => 77, 1 => 3 ),
  array( 0 => 77, 1 => 3 ),
  array( 0 => 77, 1 => 3 ),
  array( 0 => 75, 1 => 1 ),
  array( 0 => 75, 1 => 1 ),
  array( 0 => 75, 1 => 1 ),
  array( 0 => 75, 1 => 2 ),
  array( 0 => 75, 1 => 2 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 2 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 75, 1 => 3 ),
  array( 0 => 83, 1 => 4 ),
  array( 0 => 84, 1 => 5 ),
  array( 0 => 84, 1 => 5 ),
  array( 0 => 84, 1 => 5 ),
  array( 0 => 84, 1 => 4 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 3 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 3 ),
  array( 0 => 74, 1 => 3 ),
  array( 0 => 74, 1 => 3 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 3 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 2 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 1 ),
  array( 0 => 74, 1 => 3 ),
  array( 0 => 90, 1 => 1 ),
  array( 0 => 90, 1 => 1 ),
  array( 0 => 73, 1 => 1 ),
  array( 0 => 73, 1 => 1 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 1 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 4 ),
  array( 0 => 73, 1 => 3 ),
  array( 0 => 73, 1 => 4 ),
  array( 0 => 70, 1 => 2 ),
  array( 0 => 70, 1 => 2 ),
  array( 0 => 95, 1 => 2 ),
  array( 0 => 95, 1 => 0 ),
  array( 0 => 96, 1 => 2 ),
  array( 0 => 96, 1 => 2 ),
  array( 0 => 96, 1 => 4 ),
  array( 0 => 96, 1 => 2 ),
  array( 0 => 96, 1 => 2 ),
  array( 0 => 96, 1 => 4 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 5 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 3 ),
  array( 0 => 96, 1 => 2 ),
  array( 0 => 80, 1 => 1 ),
  array( 0 => 80, 1 => 1 ),
  array( 0 => 80, 1 => 2 ),
  array( 0 => 97, 1 => 1 ),
  array( 0 => 97, 1 => 1 ),
  array( 0 => 97, 1 => 3 ),
  array( 0 => 94, 1 => 2 ),
  array( 0 => 98, 1 => 1 ),
  array( 0 => 98, 1 => 2 ),
  array( 0 => 99, 1 => 3 ),
  array( 0 => 99, 1 => 3 ),
  array( 0 => 99, 1 => 5 ),
  array( 0 => 99, 1 => 6 ),
  array( 0 => 99, 1 => 2 ),
  array( 0 => 89, 1 => 4 ),
  array( 0 => 100, 1 => 4 ),
  array( 0 => 100, 1 => 4 ),
  array( 0 => 101, 1 => 3 ),
  array( 0 => 101, 1 => 1 ),
  array( 0 => 101, 1 => 0 ),
  array( 0 => 76, 1 => 3 ),
  array( 0 => 76, 1 => 2 ),
  array( 0 => 102, 1 => 3 ),
  array( 0 => 102, 1 => 2 ),
  array( 0 => 81, 1 => 2 ),
  array( 0 => 81, 1 => 0 ),
  array( 0 => 103, 1 => 2 ),
  array( 0 => 103, 1 => 3 ),
  array( 0 => 103, 1 => 2 ),
  array( 0 => 92, 1 => 1 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 92, 1 => 1 ),
  array( 0 => 92, 1 => 2 ),
  array( 0 => 92, 1 => 3 ),
  array( 0 => 86, 1 => 1 ),
  array( 0 => 86, 1 => 1 ),
  array( 0 => 85, 1 => 1 ),
  array( 0 => 87, 1 => 1 ),
  array( 0 => 93, 1 => 3 ),
  array( 0 => 93, 1 => 3 ),
  array( 0 => 104, 1 => 1 ),
  array( 0 => 104, 1 => 3 ),
  array( 0 => 104, 1 => 0 ),
  array( 0 => 105, 1 => 3 ),
  array( 0 => 105, 1 => 3 ),
  array( 0 => 105, 1 => 1 ),
  array( 0 => 91, 1 => 2 ),
  array( 0 => 91, 1 => 3 ),
  array( 0 => 106, 1 => 2 ),
  array( 0 => 106, 1 => 1 ),
  array( 0 => 107, 1 => 3 ),
  array( 0 => 107, 1 => 3 ),
  array( 0 => 107, 1 => 1 ),
  array( 0 => 107, 1 => 3 ),
  array( 0 => 107, 1 => 3 ),
  array( 0 => 107, 1 => 1 ),
  array( 0 => 107, 1 => 1 ),
    );

    public static $yyReduceMap = array(
        0 => 0,
        1 => 1,
        2 => 2,
        3 => 3,
        4 => 4,
        5 => 5,
        6 => 6,
        21 => 6,
        22 => 6,
        23 => 6,
        35 => 6,
        55 => 6,
        56 => 6,
        64 => 6,
        65 => 6,
        66 => 6,
        82 => 6,
        87 => 6,
        88 => 6,
        93 => 6,
        97 => 6,
        98 => 6,
        102 => 6,
        103 => 6,
        105 => 6,
        110 => 6,
        174 => 6,
        179 => 6,
        7 => 7,
        8 => 8,
        9 => 9,
        11 => 11,
        12 => 12,
        13 => 13,
        14 => 14,
        15 => 15,
        16 => 16,
        17 => 17,
        18 => 18,
        19 => 19,
        20 => 20,
        24 => 24,
        25 => 25,
        26 => 26,
        27 => 27,
        28 => 28,
        29 => 29,
        30 => 30,
        32 => 30,
        31 => 31,
        33 => 33,
        34 => 34,
        36 => 36,
        37 => 37,
        38 => 38,
        39 => 39,
        40 => 40,
        41 => 41,
        42 => 42,
        43 => 43,
        44 => 44,
        45 => 45,
        46 => 46,
        47 => 47,
        48 => 48,
        49 => 49,
        58 => 49,
        152 => 49,
        156 => 49,
        160 => 49,
        162 => 49,
        50 => 50,
        153 => 50,
        159 => 50,
        51 => 51,
        52 => 52,
        53 => 52,
        54 => 54,
        137 => 54,
        57 => 57,
        59 => 59,
        60 => 60,
        61 => 60,
        62 => 62,
        63 => 63,
        67 => 67,
        68 => 68,
        69 => 69,
        70 => 70,
        71 => 70,
        72 => 72,
        73 => 73,
        74 => 74,
        75 => 75,
        76 => 76,
        77 => 77,
        78 => 78,
        79 => 79,
        80 => 79,
        81 => 81,
        83 => 83,
        85 => 83,
        86 => 83,
        117 => 83,
        84 => 84,
        89 => 89,
        90 => 90,
        91 => 91,
        92 => 92,
        94 => 94,
        95 => 95,
        96 => 95,
        99 => 99,
        100 => 100,
        101 => 101,
        104 => 104,
        106 => 106,
        107 => 107,
        108 => 108,
        109 => 109,
        111 => 111,
        112 => 112,
        113 => 113,
        114 => 114,
        115 => 115,
        116 => 116,
        118 => 118,
        176 => 118,
        119 => 119,
        120 => 120,
        121 => 121,
        122 => 122,
        123 => 123,
        124 => 124,
        132 => 124,
        125 => 125,
        126 => 126,
        127 => 127,
        128 => 127,
        130 => 127,
        131 => 127,
        129 => 129,
        133 => 133,
        134 => 134,
        135 => 135,
        180 => 135,
        136 => 136,
        138 => 138,
        139 => 139,
        140 => 140,
        141 => 141,
        142 => 142,
        143 => 143,
        144 => 144,
        145 => 145,
        146 => 146,
        147 => 147,
        148 => 148,
        149 => 149,
        150 => 150,
        151 => 151,
        154 => 154,
        155 => 155,
        157 => 157,
        158 => 158,
        161 => 161,
        163 => 163,
        164 => 164,
        165 => 165,
        166 => 166,
        167 => 167,
        168 => 168,
        169 => 169,
        170 => 170,
        171 => 171,
        172 => 172,
        173 => 172,
        175 => 175,
        177 => 177,
        178 => 178,
        181 => 181,
        182 => 182,
        183 => 183,
        184 => 184,
        187 => 184,
        185 => 185,
        188 => 185,
        186 => 186,
        189 => 189,
        190 => 190,
    );
// line 245 "src/Parser/TemplateParser.y"
    public function yy_r0(){
    $this->root_buffer->prepend_array($this, $this->template_prefix);
    $this->root_buffer->append_array($this, $this->template_postfix);
    $this->_retvalue = $this->root_buffer->to_smarty_php($this);
    }
// line 252 "src/Parser/TemplateParser.y"
    public function yy_r1(){
         $text = $this->yystack[ $this->yyidx + 0 ]->minor;

         if ((string)$text == '') {
            $this->current_buffer->append_subtree($this, null);
         }

         $this->current_buffer->append_subtree($this, new \Smarty\ParseTree\Text($text, $this->strip));
    }
// line 262 "src/Parser/TemplateParser.y"
    public function yy_r2(){
    $this->strip = true;
    }
// line 266 "src/Parser/TemplateParser.y"
    public function yy_r3(){
    $this->strip = false;
    }
// line 271 "src/Parser/TemplateParser.y"
    public function yy_r4(){
       $this->current_buffer->append_subtree($this, new \Smarty\ParseTree\Text($this->yystack[$this->yyidx + -1]->minor));
    }
// line 276 "src/Parser/TemplateParser.y"
    public function yy_r5(){
    $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor.$this->yystack[$this->yyidx + -1]->minor;
    }
// line 279 "src/Parser/TemplateParser.y"
    public function yy_r6(){
    $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
    }
// line 283 "src/Parser/TemplateParser.y"
    public function yy_r7(){
        $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;

    }
// line 288 "src/Parser/TemplateParser.y"
    public function yy_r8(){
    $this->_retvalue = '';
    }
// line 292 "src/Parser/TemplateParser.y"
    public function yy_r9(){
      if ($this->compiler->has_code) {
          $this->current_buffer->append_subtree($this, $this->mergePrefixCode($this->yystack[$this->yyidx + 0]->minor));
      }
     $this->compiler->has_variable_string = false;
     $this->block_nesting_level = $this->compiler->getTagStackCount();
    }
// line 304 "src/Parser/TemplateParser.y"
    public function yy_r11(){
    $var = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->compiler->getLdelLength(), -$this->compiler->getRdelLength()), ' $');
    $attributes = [];
    if (preg_match('/^(.*)(\s+nocache)$/', $var, $match)) {
        $attributes[] = 'nocache';
        $var = $match[1];
    }
    $this->_retvalue = $this->compiler->compilePrintExpression($this->compiler->compileVariable('\''.$var.'\''), $attributes);
    }
// line 315 "src/Parser/TemplateParser.y"
    public function yy_r12(){
    $tag = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->compiler->getLdelLength(), -$this->compiler->getRdelLength()));
    if ($tag == 'strip') {
        $this->strip = true;
        $this->_retvalue = null;
    } else {
        if (defined($tag)) {
            if ($this->security) {
               $this->security->isTrustedConstant($tag, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compilePrintExpression($tag);
        } else {
            if (preg_match('/^(.*)(\s+nocache)$/', $tag, $match)) {
                $this->_retvalue = $this->compiler->compileTag($match[1],array('\'nocache\''));
            } else {
                $this->_retvalue = $this->compiler->compileTag($tag,array());
            }
        }
    }
    }
// line 336 "src/Parser/TemplateParser.y"
    public function yy_r13(){
    $j = strrpos($this->yystack[$this->yyidx + 0]->minor,'.');
    if ($this->yystack[$this->yyidx + 0]->minor[$j+1] == 'c') {
        // {$smarty.block.child}
        $this->_retvalue = $this->compiler->compileChildBlock();
    } else {
        // {$smarty.block.parent}
       $this->_retvalue = $this->compiler->compileParentBlock();
     }
    }
// line 347 "src/Parser/TemplateParser.y"
    public function yy_r14(){
    $this->_retvalue  = $this->yystack[$this->yyidx + -1]->minor;
    }
// line 351 "src/Parser/TemplateParser.y"
    public function yy_r15(){
     $this->_retvalue  = $this->yystack[$this->yyidx + -1]->minor;
     }
// line 355 "src/Parser/TemplateParser.y"
    public function yy_r16(){
    $this->_retvalue = $this->compiler->compilePrintExpression($this->yystack[$this->yyidx + 0]->minor[0], $this->yystack[$this->yyidx + 0]->minor[1]);
    }
// line 364 "src/Parser/TemplateParser.y"
    public function yy_r17(){
    $this->_retvalue = $this->compiler->compileTag('assign',array_merge(array(array('value'=>$this->yystack[$this->yyidx + 0]->minor[0]),array('var'=>'\''.substr($this->yystack[$this->yyidx + -1]->minor,1).'\'')),$this->yystack[$this->yyidx + 0]->minor[1]));
    }
// line 368 "src/Parser/TemplateParser.y"
    public function yy_r18(){
    $this->_retvalue = $this->compiler->compileTag('assign',array_merge(array(array('value'=>$this->yystack[$this->yyidx + 0]->minor[0]),array('var'=>$this->yystack[$this->yyidx + -1]->minor['var'])),$this->yystack[$this->yyidx + 0]->minor[1]),array('smarty_internal_index'=>$this->yystack[$this->yyidx + -1]->minor['smarty_internal_index']));
    }
// line 372 "src/Parser/TemplateParser.y"
    public function yy_r19(){
       $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
    }
// line 376 "src/Parser/TemplateParser.y"
    public function yy_r20(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor);
    }
// line 391 "src/Parser/TemplateParser.y"
    public function yy_r24(){
        if (defined($this->yystack[$this->yyidx + -1]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + -1]->minor, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compilePrintExpression($this->yystack[$this->yyidx + -1]->minor, $this->yystack[$this->yyidx + 0]->minor);
        } else {
            $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor);
        }
    }
// line 401 "src/Parser/TemplateParser.y"
    public function yy_r25(){
        if (defined($this->yystack[$this->yyidx + 0]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compilePrintExpression($this->yystack[$this->yyidx + 0]->minor);
        } else {
            $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + 0]->minor,array());
        }
    }
// line 414 "src/Parser/TemplateParser.y"
    public function yy_r26(){
        if (defined($this->yystack[$this->yyidx + -2]->minor)) {
            if ($this->security) {
                $this->security->isTrustedConstant($this->yystack[$this->yyidx + -2]->minor, $this->compiler);
            }
            $this->_retvalue = $this->compiler->compilePrintExpression($this->yystack[$this->yyidx + -2]->minor, $this->yystack[$this->yyidx + 0]->minor, $this->yystack[$this->yyidx + -1]->minor);
        } else {
            $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -2]->minor,$this->yystack[$this->yyidx + 0]->minor, array('modifierlist'=>$this->yystack[$this->yyidx + -1]->minor));
        }
    }
// line 426 "src/Parser/TemplateParser.y"
    public function yy_r27(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor,$this->yystack[$this->yyidx + 0]->minor,array('object_method'=>$this->yystack[$this->yyidx + -1]->minor));
    }
// line 431 "src/Parser/TemplateParser.y"
    public function yy_r28(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -4]->minor,$this->yystack[$this->yyidx + 0]->minor,array('modifierlist'=>$this->yystack[$this->yyidx + -1]->minor, 'object_method'=>$this->yystack[$this->yyidx + -2]->minor));
    }
// line 436 "src/Parser/TemplateParser.y"
    public function yy_r29(){
    $tag = trim(substr($this->yystack[$this->yyidx + -1]->minor,$this->compiler->getLdelLength())); 
    $this->_retvalue = $this->compiler->compileTag(($tag === 'else if')? 'elseif' : $tag,array(),array('if condition'=>$this->yystack[$this->yyidx + 0]->minor));
    }
// line 441 "src/Parser/TemplateParser.y"
    public function yy_r30(){
    $tag = trim(substr($this->yystack[$this->yyidx + -2]->minor,$this->compiler->getLdelLength()));
    $this->_retvalue = $this->compiler->compileTag(($tag === 'else if')? 'elseif' : $tag,$this->yystack[$this->yyidx + 0]->minor,array('if condition'=>$this->yystack[$this->yyidx + -1]->minor));
    }
// line 446 "src/Parser/TemplateParser.y"
    public function yy_r31(){
    $tag = trim(substr($this->yystack[$this->yyidx + -1]->minor,$this->compiler->getLdelLength()));
    $this->_retvalue = $this->compiler->compileTag(($tag === 'else if')? 'elseif' : $tag,array(),array('if condition'=>$this->yystack[$this->yyidx + 0]->minor));
    }
// line 457 "src/Parser/TemplateParser.y"
    public function yy_r33(){
    $this->_retvalue = $this->compiler->compileTag('for',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('start'=>$this->yystack[$this->yyidx + -6]->minor),array('ifexp'=>$this->yystack[$this->yyidx + -4]->minor),array('var'=>$this->yystack[$this->yyidx + -2]->minor),array('step'=>$this->yystack[$this->yyidx + -1]->minor))),1);
    }
// line 461 "src/Parser/TemplateParser.y"
    public function yy_r34(){
    $this->_retvalue = '='.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 469 "src/Parser/TemplateParser.y"
    public function yy_r36(){
    $this->_retvalue = $this->compiler->compileTag('for',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('start'=>$this->yystack[$this->yyidx + -3]->minor),array('to'=>$this->yystack[$this->yyidx + -1]->minor))),0);
    }
// line 473 "src/Parser/TemplateParser.y"
    public function yy_r37(){
    $this->_retvalue = $this->compiler->compileTag('for',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('start'=>$this->yystack[$this->yyidx + -5]->minor),array('to'=>$this->yystack[$this->yyidx + -3]->minor),array('step'=>$this->yystack[$this->yyidx + -1]->minor))),0);
    }
// line 478 "src/Parser/TemplateParser.y"
    public function yy_r38(){
    $this->_retvalue = $this->compiler->compileTag('foreach',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('from'=>$this->yystack[$this->yyidx + -3]->minor),array('item'=>$this->yystack[$this->yyidx + -1]->minor))));
    }
// line 482 "src/Parser/TemplateParser.y"
    public function yy_r39(){
    $this->_retvalue = $this->compiler->compileTag('foreach',array_merge($this->yystack[$this->yyidx + 0]->minor,array(array('from'=>$this->yystack[$this->yyidx + -5]->minor),array('item'=>$this->yystack[$this->yyidx + -1]->minor),array('key'=>$this->yystack[$this->yyidx + -3]->minor))));
    }
// line 485 "src/Parser/TemplateParser.y"
    public function yy_r40(){
    $this->_retvalue = $this->compiler->compileTag('foreach',$this->yystack[$this->yyidx + 0]->minor);
    }
// line 490 "src/Parser/TemplateParser.y"
    public function yy_r41(){
    $this->_retvalue = $this->compiler->compileTag('setfilter',array(),array('modifier_list'=>array(array_merge(array($this->yystack[$this->yyidx + -1]->minor),$this->yystack[$this->yyidx + 0]->minor))));
    }
// line 494 "src/Parser/TemplateParser.y"
    public function yy_r42(){
    $this->_retvalue = $this->compiler->compileTag('setfilter',array(),array('modifier_list'=>array_merge(array(array_merge(array($this->yystack[$this->yyidx + -2]->minor),$this->yystack[$this->yyidx + -1]->minor)),$this->yystack[$this->yyidx + 0]->minor)));
    }
// line 500 "src/Parser/TemplateParser.y"
    public function yy_r43(){
    $tag = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->compiler->getLdelLength(), -$this->compiler->getRdelLength()), ' /');
    if ($tag === 'strip') {
        $this->strip = false;
        $this->_retvalue = null;
    } else {
       $this->_retvalue = $this->compiler->compileTag($tag.'close',array());
    }
     }
// line 509 "src/Parser/TemplateParser.y"
    public function yy_r44(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + 0]->minor.'close',array());
    }
// line 513 "src/Parser/TemplateParser.y"
    public function yy_r45(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -1]->minor.'close',array(),array('modifier_list'=>$this->yystack[$this->yyidx + 0]->minor));
    }
// line 518 "src/Parser/TemplateParser.y"
    public function yy_r46(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -2]->minor.'close',array(),array('object_method'=>$this->yystack[$this->yyidx + 0]->minor));
    }
// line 522 "src/Parser/TemplateParser.y"
    public function yy_r47(){
    $this->_retvalue = $this->compiler->compileTag($this->yystack[$this->yyidx + -3]->minor.'close',array(),array('object_method'=>$this->yystack[$this->yyidx + -1]->minor, 'modifier_list'=>$this->yystack[$this->yyidx + 0]->minor));
    }
// line 530 "src/Parser/TemplateParser.y"
    public function yy_r48(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor;
    $this->_retvalue[] = $this->yystack[$this->yyidx + 0]->minor;
    }
// line 536 "src/Parser/TemplateParser.y"
    public function yy_r49(){
    $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor);
    }
// line 541 "src/Parser/TemplateParser.y"
    public function yy_r50(){
    $this->_retvalue = array();
    }
// line 546 "src/Parser/TemplateParser.y"
    public function yy_r51(){
    if (defined($this->yystack[$this->yyidx + 0]->minor)) {
        if ($this->security) {
            $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
        }
        $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>$this->yystack[$this->yyidx + 0]->minor);
    } else {
        $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>'\''.$this->yystack[$this->yyidx + 0]->minor.'\'');
    }
    }
// line 557 "src/Parser/TemplateParser.y"
    public function yy_r52(){
    $this->_retvalue = array(trim($this->yystack[$this->yyidx + -1]->minor," =\n\r\t")=>$this->yystack[$this->yyidx + 0]->minor);
    }
// line 565 "src/Parser/TemplateParser.y"
    public function yy_r54(){
    $this->_retvalue = '\''.$this->yystack[$this->yyidx + 0]->minor.'\'';
    }
// line 577 "src/Parser/TemplateParser.y"
    public function yy_r57(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor=>$this->yystack[$this->yyidx + 0]->minor);
    }
// line 590 "src/Parser/TemplateParser.y"
    public function yy_r59(){
    $this->yystack[$this->yyidx + -2]->minor[]=$this->yystack[$this->yyidx + 0]->minor;
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor;
    }
// line 595 "src/Parser/TemplateParser.y"
    public function yy_r60(){
    $this->_retvalue = array('var' => '\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'\'', 'value'=>$this->yystack[$this->yyidx + 0]->minor);
    }
// line 602 "src/Parser/TemplateParser.y"
    public function yy_r62(){
    $this->_retvalue = array('var' => $this->yystack[$this->yyidx + -2]->minor, 'value'=>$this->yystack[$this->yyidx + 0]->minor);
    }
// line 606 "src/Parser/TemplateParser.y"
    public function yy_r63(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor;
    }
// line 631 "src/Parser/TemplateParser.y"
    public function yy_r67(){
	$this->_retvalue = '$_smarty_tpl->getVariable(\''. substr($this->yystack[$this->yyidx + 0]->minor,1) .'\')->preIncDec(\'' . $this->yystack[$this->yyidx + -1]->minor . '\')';
    }
// line 636 "src/Parser/TemplateParser.y"
    public function yy_r68(){
	$this->_retvalue = '$_smarty_tpl->getVariable(\''. substr($this->yystack[$this->yyidx + -1]->minor,1) .'\')->postIncDec(\'' . $this->yystack[$this->yyidx + 0]->minor . '\')';
    }
// line 641 "src/Parser/TemplateParser.y"
    public function yy_r69(){
    $this->_retvalue = '$_smarty_tpl->getStreamVariable(\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'://' . $this->yystack[$this->yyidx + 0]->minor . '\')';
    }
// line 646 "src/Parser/TemplateParser.y"
    public function yy_r70(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor . trim($this->yystack[$this->yyidx + -1]->minor) . $this->yystack[$this->yyidx + 0]->minor;
    }
// line 656 "src/Parser/TemplateParser.y"
    public function yy_r72(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor['pre']. $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor['op'].$this->yystack[$this->yyidx + 0]->minor .')';
    }
// line 660 "src/Parser/TemplateParser.y"
    public function yy_r73(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 664 "src/Parser/TemplateParser.y"
    public function yy_r74(){
    $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor . $this->yystack[$this->yyidx + -1]->minor . ')';
    }
// line 668 "src/Parser/TemplateParser.y"
    public function yy_r75(){
    $this->_retvalue = 'in_array('.$this->yystack[$this->yyidx + -2]->minor.','.$this->yystack[$this->yyidx + 0]->minor.')';
    }
// line 672 "src/Parser/TemplateParser.y"
    public function yy_r76(){
    $this->_retvalue = 'in_array('.$this->yystack[$this->yyidx + -2]->minor.',(array)'.$this->yystack[$this->yyidx + 0]->minor.')';
    }
// line 677 "src/Parser/TemplateParser.y"
    public function yy_r77(){
    $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor.' ?? '.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 684 "src/Parser/TemplateParser.y"
    public function yy_r78(){
    $this->_retvalue = $this->yystack[$this->yyidx + -4]->minor.' ? '. $this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + -2]->minor,1).'\'') . ' : '.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 688 "src/Parser/TemplateParser.y"
    public function yy_r79(){
    $this->_retvalue = $this->yystack[$this->yyidx + -4]->minor.' ? '.$this->yystack[$this->yyidx + -2]->minor.' : '.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 697 "src/Parser/TemplateParser.y"
    public function yy_r81(){
    $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor.' ?: '.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 707 "src/Parser/TemplateParser.y"
    public function yy_r83(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 712 "src/Parser/TemplateParser.y"
    public function yy_r84(){
    $this->_retvalue = '!'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 733 "src/Parser/TemplateParser.y"
    public function yy_r89(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'.'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 737 "src/Parser/TemplateParser.y"
    public function yy_r90(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.'.';
    }
// line 741 "src/Parser/TemplateParser.y"
    public function yy_r91(){
    $this->_retvalue = '.'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 746 "src/Parser/TemplateParser.y"
    public function yy_r92(){
    if (defined($this->yystack[$this->yyidx + 0]->minor)) {
        if ($this->security) {
             $this->security->isTrustedConstant($this->yystack[$this->yyidx + 0]->minor, $this->compiler);
        }
        $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
    } else {
        $this->_retvalue = '\''.$this->yystack[$this->yyidx + 0]->minor.'\'';
    }
    }
// line 763 "src/Parser/TemplateParser.y"
    public function yy_r94(){
    $this->_retvalue = '('. $this->yystack[$this->yyidx + -1]->minor .')';
    }
// line 767 "src/Parser/TemplateParser.y"
    public function yy_r95(){
      $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 785 "src/Parser/TemplateParser.y"
    public function yy_r99(){
    if ($this->security && $this->security->static_classes !== array()) {
        $this->compiler->trigger_template_error('dynamic static class not allowed by security setting');
    }
    $prefixVar = $this->compiler->getNewPrefixVariable();
    if ($this->yystack[$this->yyidx + -2]->minor['var'] === '\'smarty\'') {
        $this->compiler->appendPrefixCode("<?php {$prefixVar} = ". (new \Smarty\Compile\SpecialVariableCompiler())->compile(array(),$this->compiler,$this->yystack[$this->yyidx + -2]->minor['smarty_internal_index']).';?>');
     } else {
        $this->compiler->appendPrefixCode("<?php  {$prefixVar} = ". $this->compiler->compileVariable($this->yystack[$this->yyidx + -2]->minor['var']).$this->yystack[$this->yyidx + -2]->minor['smarty_internal_index'].';?>');
    }
    $this->_retvalue = $prefixVar .'::'.$this->yystack[$this->yyidx + 0]->minor[0].$this->yystack[$this->yyidx + 0]->minor[1];
    }
// line 799 "src/Parser/TemplateParser.y"
    public function yy_r100(){
    $prefixVar = $this->compiler->getNewPrefixVariable();
    $tmp = $this->compiler->appendCode('<?php ob_start();?>', $this->yystack[$this->yyidx + 0]->minor);
    $this->compiler->appendPrefixCode($this->compiler->appendCode($tmp, "<?php {$prefixVar} = ob_get_clean();?>"));
    $this->_retvalue = $prefixVar;
    }
// line 806 "src/Parser/TemplateParser.y"
    public function yy_r101(){
    $this->_retvalue = $this->compiler->compileModifier($this->yystack[$this->yyidx + 0]->minor, $this->yystack[$this->yyidx + -1]->minor);
    }
// line 819 "src/Parser/TemplateParser.y"
    public function yy_r104(){
    if (!in_array(strtolower($this->yystack[$this->yyidx + -2]->minor), array('self', 'parent')) && (!$this->security || $this->security->isTrustedStaticClassAccess($this->yystack[$this->yyidx + -2]->minor, $this->yystack[$this->yyidx + 0]->minor, $this->compiler))) {
        if (isset($this->smarty->registered_classes[$this->yystack[$this->yyidx + -2]->minor])) {
            $this->_retvalue = $this->smarty->registered_classes[$this->yystack[$this->yyidx + -2]->minor].'::'.$this->yystack[$this->yyidx + 0]->minor[0].$this->yystack[$this->yyidx + 0]->minor[1];
        } else {
            $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'::'.$this->yystack[$this->yyidx + 0]->minor[0].$this->yystack[$this->yyidx + 0]->minor[1];
        } 
    } else {
        $this->compiler->trigger_template_error ('static class \''.$this->yystack[$this->yyidx + -2]->minor.'\' is undefined or not allowed by security setting');
    }
    }
// line 838 "src/Parser/TemplateParser.y"
    public function yy_r106(){
    $this->_retvalue = $this->yystack[$this->yyidx + 0]->minor;
        }
// line 849 "src/Parser/TemplateParser.y"
    public function yy_r107(){
   $this->_retvalue = $this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + 0]->minor,1).'\'');
    }
// line 852 "src/Parser/TemplateParser.y"
    public function yy_r108(){
    if ($this->yystack[$this->yyidx + 0]->minor['var'] === '\'smarty\'') {
        $smarty_var = (new \Smarty\Compile\SpecialVariableCompiler())->compile(array(),$this->compiler,$this->yystack[$this->yyidx + 0]->minor['smarty_internal_index']);
        $this->_retvalue = $smarty_var;
    } else {
        // used for array reset,next,prev,end,current 
        $this->last_variable = $this->yystack[$this->yyidx + 0]->minor['var'];
        $this->last_index = $this->yystack[$this->yyidx + 0]->minor['smarty_internal_index'];
        $this->_retvalue = $this->compiler->compileVariable($this->yystack[$this->yyidx + 0]->minor['var']).$this->yystack[$this->yyidx + 0]->minor['smarty_internal_index'];
    }
    }
// line 865 "src/Parser/TemplateParser.y"
    public function yy_r109(){
    $this->_retvalue = '$_smarty_tpl->getVariable('. $this->yystack[$this->yyidx + -2]->minor .')->'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 875 "src/Parser/TemplateParser.y"
    public function yy_r111(){
    $this->_retvalue = $this->compiler->compileConfigVariable('\'' . $this->yystack[$this->yyidx + -1]->minor . '\'');
    }
// line 879 "src/Parser/TemplateParser.y"
    public function yy_r112(){
    $this->_retvalue = '(is_array($tmp = ' . $this->compiler->compileConfigVariable('\'' . $this->yystack[$this->yyidx + -2]->minor . '\'') . ') ? $tmp'.$this->yystack[$this->yyidx + 0]->minor.' :null)';
    }
// line 883 "src/Parser/TemplateParser.y"
    public function yy_r113(){
    $this->_retvalue = $this->compiler->compileConfigVariable($this->yystack[$this->yyidx + -1]->minor);
    }
// line 887 "src/Parser/TemplateParser.y"
    public function yy_r114(){
    $this->_retvalue = '(is_array($tmp = ' . $this->compiler->compileConfigVariable($this->yystack[$this->yyidx + -2]->minor) . ') ? $tmp'.$this->yystack[$this->yyidx + 0]->minor.' : null)';
    }
// line 891 "src/Parser/TemplateParser.y"
    public function yy_r115(){
    $this->_retvalue = array('var'=>'\''.substr($this->yystack[$this->yyidx + -1]->minor,1).'\'', 'smarty_internal_index'=>$this->yystack[$this->yyidx + 0]->minor);
    }
// line 894 "src/Parser/TemplateParser.y"
    public function yy_r116(){
    $this->_retvalue = array('var'=>$this->yystack[$this->yyidx + -1]->minor, 'smarty_internal_index'=>$this->yystack[$this->yyidx + 0]->minor);
    }
// line 907 "src/Parser/TemplateParser.y"
    public function yy_r118(){
    return;
    }
// line 913 "src/Parser/TemplateParser.y"
    public function yy_r119(){
    $this->_retvalue = '['.$this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + 0]->minor,1).'\'').']';
    }
// line 916 "src/Parser/TemplateParser.y"
    public function yy_r120(){
    $this->_retvalue = '['.$this->compiler->compileVariable($this->yystack[$this->yyidx + 0]->minor).']';
    }
// line 920 "src/Parser/TemplateParser.y"
    public function yy_r121(){
    $this->_retvalue = '['.$this->compiler->compileVariable($this->yystack[$this->yyidx + -2]->minor).'->'.$this->yystack[$this->yyidx + 0]->minor.']';
    }
// line 924 "src/Parser/TemplateParser.y"
    public function yy_r122(){
    $this->_retvalue = '[\''. $this->yystack[$this->yyidx + 0]->minor .'\']';
    }
// line 928 "src/Parser/TemplateParser.y"
    public function yy_r123(){
    $this->_retvalue = '['. $this->yystack[$this->yyidx + 0]->minor .']';
    }
// line 933 "src/Parser/TemplateParser.y"
    public function yy_r124(){
    $this->_retvalue = '['. $this->yystack[$this->yyidx + -1]->minor .']';
    }
// line 938 "src/Parser/TemplateParser.y"
    public function yy_r125(){
    $this->_retvalue = '['.(new \Smarty\Compile\SpecialVariableCompiler())->compile(array(),$this->compiler,'[\'section\'][\''.$this->yystack[$this->yyidx + -1]->minor.'\'][\'index\']').']';
    }
// line 942 "src/Parser/TemplateParser.y"
    public function yy_r126(){
    $this->_retvalue = '['.(new \Smarty\Compile\SpecialVariableCompiler())->compile(array(),$this->compiler,'[\'section\'][\''.$this->yystack[$this->yyidx + -3]->minor.'\'][\''.$this->yystack[$this->yyidx + -1]->minor.'\']').']';
    }
// line 945 "src/Parser/TemplateParser.y"
    public function yy_r127(){
    $this->_retvalue = '['.$this->yystack[$this->yyidx + -1]->minor.']';
    }
// line 951 "src/Parser/TemplateParser.y"
    public function yy_r129(){
    $this->_retvalue = '['.$this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + -1]->minor,1).'\'').']';
    }
// line 967 "src/Parser/TemplateParser.y"
    public function yy_r133(){
    $this->_retvalue = '[]';
    }
// line 977 "src/Parser/TemplateParser.y"
    public function yy_r134(){
    $this->_retvalue = '\''.substr($this->yystack[$this->yyidx + 0]->minor,1).'\'';
    }
// line 981 "src/Parser/TemplateParser.y"
    public function yy_r135(){
    $this->_retvalue = '\'\'';
    }
// line 986 "src/Parser/TemplateParser.y"
    public function yy_r136(){
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor.'.'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 994 "src/Parser/TemplateParser.y"
    public function yy_r138(){
    $var = trim(substr($this->yystack[$this->yyidx + 0]->minor, $this->compiler->getLdelLength(), -$this->compiler->getRdelLength()), ' $');
    $this->_retvalue = $this->compiler->compileVariable('\''.$var.'\'');
    }
// line 1000 "src/Parser/TemplateParser.y"
    public function yy_r139(){
    $this->_retvalue = '('.$this->yystack[$this->yyidx + -1]->minor.')';
    }
// line 1007 "src/Parser/TemplateParser.y"
    public function yy_r140(){
    if ($this->yystack[$this->yyidx + -1]->minor['var'] === '\'smarty\'') {
        $this->_retvalue = (new \Smarty\Compile\SpecialVariableCompiler())->compile(array(),$this->compiler,$this->yystack[$this->yyidx + -1]->minor['smarty_internal_index']).$this->yystack[$this->yyidx + 0]->minor;
    } else {
        $this->_retvalue = $this->compiler->compileVariable($this->yystack[$this->yyidx + -1]->minor['var']).$this->yystack[$this->yyidx + -1]->minor['smarty_internal_index'].$this->yystack[$this->yyidx + 0]->minor;
    }
    }
// line 1016 "src/Parser/TemplateParser.y"
    public function yy_r141(){
    $this->_retvalue  = $this->yystack[$this->yyidx + 0]->minor;
    }
// line 1021 "src/Parser/TemplateParser.y"
    public function yy_r142(){
    $this->_retvalue  = $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 1026 "src/Parser/TemplateParser.y"
    public function yy_r143(){
    if ($this->security && substr($this->yystack[$this->yyidx + -1]->minor,0,1) === '_') {
        $this->compiler->trigger_template_error (self::ERR1);
    }
    $this->_retvalue = '->'.$this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 1033 "src/Parser/TemplateParser.y"
    public function yy_r144(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::ERR2);
    }
    $this->_retvalue = '->{'.$this->compiler->compileVariable($this->yystack[$this->yyidx + -1]->minor).$this->yystack[$this->yyidx + 0]->minor.'}';
    }
// line 1040 "src/Parser/TemplateParser.y"
    public function yy_r145(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::ERR2);
    }
    $this->_retvalue = '->{'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';
    }
// line 1047 "src/Parser/TemplateParser.y"
    public function yy_r146(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::ERR2);
    }
    $this->_retvalue = '->{\''.$this->yystack[$this->yyidx + -4]->minor.'\'.'.$this->yystack[$this->yyidx + -2]->minor.$this->yystack[$this->yyidx + 0]->minor.'}';
    }
// line 1055 "src/Parser/TemplateParser.y"
    public function yy_r147(){
    $this->_retvalue = '->'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 1063 "src/Parser/TemplateParser.y"
    public function yy_r148(){
    $this->_retvalue = $this->compiler->compileModifierInExpression($this->yystack[$this->yyidx + -3]->minor, $this->yystack[$this->yyidx + -1]->minor);
    }
// line 1071 "src/Parser/TemplateParser.y"
    public function yy_r149(){
    if ($this->security && substr($this->yystack[$this->yyidx + -3]->minor,0,1) === '_') {
        $this->compiler->trigger_template_error (self::ERR1);
    }
    $this->_retvalue = $this->yystack[$this->yyidx + -3]->minor . '('. implode(',',$this->yystack[$this->yyidx + -1]->minor) .')';
    }
// line 1078 "src/Parser/TemplateParser.y"
    public function yy_r150(){
    if ($this->security) {
        $this->compiler->trigger_template_error (self::ERR2);
    }
    $prefixVar = $this->compiler->getNewPrefixVariable();
    $this->compiler->appendPrefixCode("<?php {$prefixVar} = ".$this->compiler->compileVariable('\''.substr($this->yystack[$this->yyidx + -3]->minor,1).'\'').';?>');
    $this->_retvalue = $prefixVar .'('. implode(',',$this->yystack[$this->yyidx + -1]->minor) .')';
    }
// line 1089 "src/Parser/TemplateParser.y"
    public function yy_r151(){
    $this->_retvalue = array_merge($this->yystack[$this->yyidx + -2]->minor,array($this->yystack[$this->yyidx + 0]->minor));
    }
// line 1106 "src/Parser/TemplateParser.y"
    public function yy_r154(){
    $this->_retvalue = array_merge($this->yystack[$this->yyidx + -2]->minor,array(array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor)));
    }
// line 1110 "src/Parser/TemplateParser.y"
    public function yy_r155(){
    $this->_retvalue = array(array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor));
    }
// line 1118 "src/Parser/TemplateParser.y"
    public function yy_r157(){
    $this->_retvalue =  array($this->yystack[$this->yyidx + 0]->minor);
    }
// line 1126 "src/Parser/TemplateParser.y"
    public function yy_r158(){
    $this->_retvalue = array_merge($this->yystack[$this->yyidx + -1]->minor,$this->yystack[$this->yyidx + 0]->minor);
    }
// line 1139 "src/Parser/TemplateParser.y"
    public function yy_r161(){
    $this->_retvalue = array(trim($this->yystack[$this->yyidx + -1]->minor).$this->yystack[$this->yyidx + 0]->minor);
    }
// line 1148 "src/Parser/TemplateParser.y"
    public function yy_r163(){
    $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor, '', 'method');
    }
// line 1153 "src/Parser/TemplateParser.y"
    public function yy_r164(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -1]->minor, $this->yystack[$this->yyidx + 0]->minor, 'method');
    }
// line 1158 "src/Parser/TemplateParser.y"
    public function yy_r165(){
    $this->_retvalue = array($this->yystack[$this->yyidx + 0]->minor, '');
    }
// line 1163 "src/Parser/TemplateParser.y"
    public function yy_r166(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -1]->minor, $this->yystack[$this->yyidx + 0]->minor, 'property');
    }
// line 1168 "src/Parser/TemplateParser.y"
    public function yy_r167(){
    $this->_retvalue = array($this->yystack[$this->yyidx + -2]->minor, $this->yystack[$this->yyidx + -1]->minor.$this->yystack[$this->yyidx + 0]->minor, 'property');
    }
// line 1174 "src/Parser/TemplateParser.y"
    public function yy_r168(){
    $this->_retvalue = ' '. trim($this->yystack[$this->yyidx + 0]->minor) . ' ';
    }
// line 1178 "src/Parser/TemplateParser.y"
    public function yy_r169(){
    static $lops = array(
        'eq' => ' == ',
        'ne' => ' != ',
        'neq' => ' != ',
        'gt' => ' > ',
        'ge' => ' >= ',
        'gte' => ' >= ',
        'lt' =>  ' < ',
        'le' =>  ' <= ',
        'lte' => ' <= ',
        'mod' =>  ' % ',
        'and' => ' && ',
        'or' => ' || ',
        'xor' => ' xor ',
         );
    $op = strtolower(preg_replace('/\s*/', '', $this->yystack[$this->yyidx + 0]->minor));
    $this->_retvalue = $lops[$op];
    }
// line 1197 "src/Parser/TemplateParser.y"
    public function yy_r170(){
     static $tlops = array(
         'isdivby' => array('op' => ' % ', 'pre' => '!('),
         'isnotdivby' => array('op' => ' % ', 'pre' => '('),
         'isevenby' => array('op' => ' / ', 'pre' => '!(1 & '),
         'isnotevenby' => array('op' => ' / ', 'pre' => '(1 & '),
         'isoddby' => array('op' => ' / ', 'pre' => '(1 & '),
         'isnotoddby' => array('op' => ' / ', 'pre' => '!(1 & '),
         );
     $op = strtolower(preg_replace('/\s*/', '', $this->yystack[$this->yyidx + 0]->minor));
     $this->_retvalue = $tlops[$op];
     }
// line 1210 "src/Parser/TemplateParser.y"
    public function yy_r171(){
        static $scond = array (
            'iseven' => '!(1 & ',
            'isnoteven' => '(1 & ',
            'isodd' => '(1 & ',
            'isnotodd' => '!(1 & ',
        );
   $op = strtolower(str_replace(' ', '', $this->yystack[$this->yyidx + 0]->minor));
   $this->_retvalue = $scond[$op];
    }
// line 1224 "src/Parser/TemplateParser.y"
    public function yy_r172(){
    $this->_retvalue = 'array('.$this->yystack[$this->yyidx + -1]->minor.')';
    }
// line 1235 "src/Parser/TemplateParser.y"
    public function yy_r175(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.','.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 1243 "src/Parser/TemplateParser.y"
    public function yy_r177(){
    $this->_retvalue = $this->yystack[$this->yyidx + -2]->minor.'=>'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 1247 "src/Parser/TemplateParser.y"
    public function yy_r178(){ 
    $this->_retvalue = '\''.$this->yystack[$this->yyidx + -2]->minor.'\'=>'.$this->yystack[$this->yyidx + 0]->minor;
    }
// line 1263 "src/Parser/TemplateParser.y"
    public function yy_r181(){
    $this->compiler->leaveDoubleQuote();
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor->to_smarty_php($this);
    }
// line 1269 "src/Parser/TemplateParser.y"
    public function yy_r182(){
    $this->yystack[$this->yyidx + -1]->minor->append_subtree($this, $this->yystack[$this->yyidx + 0]->minor);
    $this->_retvalue = $this->yystack[$this->yyidx + -1]->minor;
    }
// line 1274 "src/Parser/TemplateParser.y"
    public function yy_r183(){
    $this->_retvalue = new Dq($this, $this->yystack[$this->yyidx + 0]->minor);
    }
// line 1278 "src/Parser/TemplateParser.y"
    public function yy_r184(){
    $this->_retvalue = new Code('(string)'.$this->yystack[$this->yyidx + -1]->minor);
    }
// line 1282 "src/Parser/TemplateParser.y"
    public function yy_r185(){
    $this->_retvalue = new Code('(string)('.$this->yystack[$this->yyidx + -1]->minor.')');
    }
// line 1286 "src/Parser/TemplateParser.y"
    public function yy_r186(){
    $this->_retvalue = new Code('(string)$_smarty_tpl->getValue(\''. substr($this->yystack[$this->yyidx + 0]->minor,1) .'\')');
    }
// line 1298 "src/Parser/TemplateParser.y"
    public function yy_r189(){
    $this->_retvalue = new Tag($this, $this->yystack[$this->yyidx + 0]->minor);
    }
// line 1302 "src/Parser/TemplateParser.y"
    public function yy_r190(){
    $this->_retvalue = new DqContent($this->yystack[$this->yyidx + 0]->minor);
    }

    private $_retvalue;

    public function yy_reduce($yyruleno)
    {
        if ($this->yyTraceFILE && $yyruleno >= 0
              && $yyruleno < count(self::$yyRuleName)) {
            fprintf($this->yyTraceFILE, "%sReduce (%d) [%s].\n",
                $this->yyTracePrompt, $yyruleno,
                self::$yyRuleName[$yyruleno]);
        }

        $this->_retvalue = $yy_lefthand_side = null;
        if (isset(self::$yyReduceMap[$yyruleno])) {
            // call the action
            $this->_retvalue = null;
            $this->{'yy_r' . self::$yyReduceMap[$yyruleno]}();
            $yy_lefthand_side = $this->_retvalue;
        }
        $yygoto = self::$yyRuleInfo[$yyruleno][0];
        $yysize = self::$yyRuleInfo[$yyruleno][1];
        $this->yyidx -= $yysize;
        for ($i = $yysize; $i; $i--) {
            // pop all of the right-hand side parameters
            array_pop($this->yystack);
        }
        $yyact = $this->yy_find_reduce_action($this->yystack[$this->yyidx]->stateno, $yygoto);
        if ($yyact < self::YYNSTATE) {
            if (!$this->yyTraceFILE && $yysize) {
                $this->yyidx++;
                $x = (object) ['stateno' => null, 'major' => null, 'minor' => null];
                $x->stateno = $yyact;
                $x->major = $yygoto;
                $x->minor = $yy_lefthand_side;
                $this->yystack[$this->yyidx] = $x;
            } else {
                $this->yy_shift($yyact, $yygoto, $yy_lefthand_side);
            }
        } elseif ($yyact === self::YYNSTATE + self::YYNRULE + 1) {
            $this->yy_accept();
        }
    }

    public function yy_parse_failed()
    {
        if ($this->yyTraceFILE) {
            fprintf($this->yyTraceFILE, "%sFail!\n", $this->yyTracePrompt);
        } while ($this->yyidx >= 0) {
            $this->yy_pop_parser_stack();
        }
    }

    public function yy_syntax_error($yymajor, $TOKEN)
    {
// line 225 "src/Parser/TemplateParser.y"

    $this->internalError = true;
    $this->yymajor = $yymajor;
    $this->compiler->trigger_template_error();
    }

    public function yy_accept()
    {
        if ($this->yyTraceFILE) {
            fprintf($this->yyTraceFILE, "%sAccept!\n", $this->yyTracePrompt);
        } while ($this->yyidx >= 0) {
            $this->yy_pop_parser_stack();
        }
// line 218 "src/Parser/TemplateParser.y"

    $this->successful = !$this->internalError;
    $this->internalError = false;
    $this->retvalue = $this->_retvalue;
    }

    public function doParse($yymajor, $yytokenvalue)
    {
        $yyerrorhit = 0;   /* True if yymajor has invoked an error */

        if ($this->yyidx === null || $this->yyidx < 0) {
            $this->yyidx = 0;
            $this->yyerrcnt = -1;
            $x = (object) ['stateno' => null, 'major' => null, 'minor' => null];
            $x->stateno = 0;
            $x->major = 0;
            $this->yystack = array();
            $this->yystack[] = $x;
        }
        $yyendofinput = ($yymajor==0);

        if ($this->yyTraceFILE) {
            fprintf($this->yyTraceFILE, "%sInput %s\n",
                $this->yyTracePrompt, $this->yyTokenName[$yymajor]);
        }

        do {
            $yyact = $this->yy_find_shift_action($yymajor);
            if ($yymajor < self::YYERRORSYMBOL &&
                  !$this->yy_is_expected_token($yymajor)) {
                // force a syntax error
                $yyact = self::YY_ERROR_ACTION;
            }
            if ($yyact < self::YYNSTATE) {
                $this->yy_shift($yyact, $yymajor, $yytokenvalue);
                $this->yyerrcnt--;
                if ($yyendofinput && $this->yyidx >= 0) {
                    $yymajor = 0;
                } else {
                    $yymajor = self::YYNOCODE;
                }
            } elseif ($yyact < self::YYNSTATE + self::YYNRULE) {
                $this->yy_reduce($yyact - self::YYNSTATE);
            } elseif ($yyact === self::YY_ERROR_ACTION) {
                if ($this->yyTraceFILE) {
                    fprintf($this->yyTraceFILE, "%sSyntax Error!\n",
                        $this->yyTracePrompt);
                }
                if (self::YYERRORSYMBOL) {
                    if ($this->yyerrcnt < 0) {
                        $this->yy_syntax_error($yymajor, $yytokenvalue);
                    }
                    $yymx = $this->yystack[$this->yyidx]->major;
                    if ($yymx === self::YYERRORSYMBOL || $yyerrorhit) {
                        if ($this->yyTraceFILE) {
                            fprintf($this->yyTraceFILE, "%sDiscard input token %s\n",
                                $this->yyTracePrompt, $this->yyTokenName[$yymajor]);
                        }
                        $this->yy_destructor($yymajor, $yytokenvalue);
                        $yymajor = self::YYNOCODE;
                    } else {
                        while ($this->yyidx >= 0 &&
                                 $yymx !== self::YYERRORSYMBOL &&
        ($yyact = $this->yy_find_shift_action(self::YYERRORSYMBOL)) >= self::YYNSTATE
                              ){
                            $this->yy_pop_parser_stack();
                        }
                        if ($this->yyidx < 0 || $yymajor==0) {
                            $this->yy_destructor($yymajor, $yytokenvalue);
                            $this->yy_parse_failed();
                            $yymajor = self::YYNOCODE;
                        } elseif ($yymx !== self::YYERRORSYMBOL) {
                            $u2 = 0;
                            $this->yy_shift($yyact, self::YYERRORSYMBOL, $u2);
                        }
                    }
                    $this->yyerrcnt = 3;
                    $yyerrorhit = 1;
                } else {
                    if ($this->yyerrcnt <= 0) {
                        $this->yy_syntax_error($yymajor, $yytokenvalue);
                    }
                    $this->yyerrcnt = 3;
                    $this->yy_destructor($yymajor, $yytokenvalue);
                    if ($yyendofinput) {
                        $this->yy_parse_failed();
                    }
                    $yymajor = self::YYNOCODE;
                }
            } else {
                $this->yy_accept();
                $yymajor = self::YYNOCODE;
            }
        } while ($yymajor !== self::YYNOCODE && $this->yyidx >= 0);
    }
}

